@@ -1,29 +1,30 @@
-/*$Id: mg_main.cc,v 18.5 2000/07/10 08:36:14 al Exp $ -*- C++ -*-
+/*$Id: mg_main.cc,v 19.13 2001/03/01 09:04:34 al Exp $ -*- C++ -*-
  */
-#include "mg_.h"
+#include "mg_out.h"
+/*global*/ int errorcount = 0;
 /*--------------------------------------------------------------------------*/
 int main(int argc, char** argv)
 {
   {if (argc > 2 && strcmp(argv[1],"-h")==0) {
-    for (int i=2; i<argc; ++i) {
+    {for (int i=2; i<argc; ++i) {
       File f(argv[i]);
       make_h_file(f);
-    }
+    }}
   }else if (argc > 2 && strcmp(argv[1],"-cc")==0) {
-    for (int i=2; i<argc; ++i) {
+    {for (int i=2; i<argc; ++i) {
       File f(argv[i]);
       make_cc_file(f);
-    }
+    }}
   }else if (argc > 1) {
-    for (int i=1; i<argc; ++i) {
+    {for (int i=1; i<argc; ++i) {
       File f(argv[i]);
       make_h_file(f);
       make_cc_file(f);
-    }
+    }}
   }else{
     error("no input files");
   }}
-  return 0;
+  return errorcount;
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
