@@ -1,6 +1,7 @@
-/*$Id: bm.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: bm.cc,v 19.20 2001/05/05 07:42:40 al Exp $ -*- C++ -*-
  * behavioral modeling action base
  */
+#include "l_stlextra.h"
 #include "ap.h"
 #include "bm.h"
 /*--------------------------------------------------------------------------*/
@@ -14,24 +15,52 @@ const double _default_tc1	(0);
 const double _default_tc2	(0);
 const double _default_ic	(NOT_INPUT);
 /*--------------------------------------------------------------------------*/
-EVAL_BM_ACTION_BASE* EVAL_BM_ACTION_BASE::parse_func_type(CS& cmd)
+EVAL_DISPATCHER bm_dispatcher;
+/*--------------------------------------------------------------------------*/
+EVAL_DISPATCHER::EVAL_DISPATCHER()
 {
-  if      (cmd.is_float(	 )) return new EVAL_BM_VALUE;
-  else if (cmd.pmatch("COMPLEX"	 )) return new EVAL_BM_COMPLEX;
-  else if (cmd.pmatch("EXP"	 )) return new EVAL_BM_EXP;
-  else if (cmd.pmatch("FIT"	 )) return new EVAL_BM_FIT;
-  else if (cmd.pmatch("GENerator")) return new EVAL_BM_GENERATOR;
-  else if (cmd.pmatch("POLY(1)"	 )) return new EVAL_BM_POLY;
-  else if (cmd.pmatch("POLY"	 )) return new EVAL_BM_POLY;
-  else if (cmd.pmatch("POSY"	 )) return new EVAL_BM_POSY;
-  else if (cmd.pmatch("PULSE"    )) return new EVAL_BM_PULSE;
-  else if (cmd.pmatch("PWL(1)"   )) return new EVAL_BM_PWL;
-  else if (cmd.pmatch("PWL"      )) return new EVAL_BM_PWL;
-  else if (cmd.pmatch("SFFM"	 )) return new EVAL_BM_SFFM;
-  else if (cmd.pmatch("SIN"      )) return new EVAL_BM_SIN;
-  else if (cmd.pmatch("TANH"     )) return new EVAL_BM_TANH;
-  else if (cmd.pmatch("VALUE"    )) return new EVAL_BM_VALUE;
-  else return 0;
+  _map["complex"]  = new EVAL_BM_COMPLEX;
+  _map["exp"]	   = new EVAL_BM_EXP;
+  _map["fit"]	   = new EVAL_BM_FIT;
+  _map["generator"] =
+    _map["gen"]    = new EVAL_BM_GENERATOR;
+  _map["poly"]     = new EVAL_BM_POLY;
+  _map["posy"]     = new EVAL_BM_POSY;
+  _map["pulse"]    = new EVAL_BM_PULSE;
+  _map["pwl"]	   = new EVAL_BM_PWL;
+  _map["sffm"]     = new EVAL_BM_SFFM;
+  _map["sin"]	   = new EVAL_BM_SIN;
+  _map["tanh"]     = new EVAL_BM_TANH;
+  _map["value"]    = new EVAL_BM_VALUE;
+}
+/*--------------------------------------------------------------------------*/
+COMMON_COMPONENT* EVAL_DISPATCHER::operator()(CS& cmd)
+{
+  {if (cmd.is_float( )) {
+    return new EVAL_BM_VALUE;
+  }else{
+    int here = cmd.cursor();
+    std::string s;
+    cmd >> s;
+    to_lower(&s);
+    const COMMON_COMPONENT* p = _map[s];
+    {if (p) {
+      if (dynamic_cast<const EVAL_BM_POLY*>(p)
+	  || dynamic_cast<const EVAL_BM_PWL*>(p)) {
+	cmd.ematch("(1)"); // HSpice compatibility kluge
+      }
+      return p->clone();
+    }else{
+      cmd.reset(here);
+      return 0;
+    }}
+  }}
+}
+/*--------------------------------------------------------------------------*/
+/*--------------------------------------------------------------------------*/
+COMMON_COMPONENT* EVAL_BM_ACTION_BASE::parse_func_type(CS& cmd)
+{
+  return bm_dispatcher(cmd);
 }
 /*--------------------------------------------------------------------------*/
 EVAL_BM_ACTION_BASE::EVAL_BM_ACTION_BASE(int c)
