@@ -1,4 +1,4 @@
-/*$Id: bm.h,v 18.8 2000/07/26 09:26:27 al Exp $ -*- C++ -*-
+/*$Id: bm.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * behavioral modeling base
  */
 #ifndef E_BM_H
@@ -7,12 +7,21 @@
 /*--------------------------------------------------------------------------*/
 class SPLINE;
 /*--------------------------------------------------------------------------*/
-class EVAL_BM_BASE : public COMPONENT_COMMON {
+class EVAL_DISPATCHER {
+private:
+  std::map<std::string, COMMON_COMPONENT*> _map;
+public:
+  explicit EVAL_DISPATCHER();
+  COMMON_COMPONENT* operator()(CS& cmd);
+};
+/*--------------------------------------------------------------------------*/
+class EVAL_BM_BASE : public COMMON_COMPONENT {
 protected:
-  explicit	EVAL_BM_BASE(int c=0) :COMPONENT_COMMON(c) {}
+  explicit	EVAL_BM_BASE(int c=0) :COMMON_COMPONENT(c) {}
   explicit	EVAL_BM_BASE(const EVAL_BM_BASE& p)
-    :COMPONENT_COMMON(p) {}
+    :COMMON_COMPONENT(p) {}
 private: // override virtual
+  bool operator==(const COMMON_COMPONENT&)const {incomplete(); return false;}
   bool		has_tr_eval()const	{return true;}
   bool		has_ac_eval()const	{return true;}
 };
@@ -50,19 +59,19 @@ private: // override virtual
   bool		has_ac_eval()const	{return true;}
 public:
   bool		has_ext_args()const	{return _has_ext_args;}
-  static EVAL_BM_ACTION_BASE* parse_func_type(CS&);
+  static COMMON_COMPONENT* parse_func_type(CS&);
 };
 /*--------------------------------------------------------------------------*/
 class EVAL_BM_COND : public EVAL_BM_BASE {
 private:
-  const COMPONENT_COMMON* _func[sCOUNT];
+  COMMON_COMPONENT* _func[sCOUNT];
   bool _set[sCOUNT];
+  explicit	EVAL_BM_COND(const EVAL_BM_COND& p);
 public:
   explicit	EVAL_BM_COND(int c=0);
-protected:
-  explicit	EVAL_BM_COND(const EVAL_BM_COND& p);
 		~EVAL_BM_COND();
 private: // override virtual
+  COMMON_COMPONENT* clone()const {untested(); return new EVAL_BM_COND(*this);}
   const char*	name()const		{unreachable(); return "????";}
   void		parse(CS&);
   void		print(OMSTREAM&)const;
@@ -70,18 +79,40 @@ private: // override virtual
 		    {assert(_func[SIM::mode]); _func[SIM::mode]->tr_eval(d);}
   void		ac_eval(ELEMENT*d)const
 		    {assert(_func[sAC]); _func[sAC]->ac_eval(d);}
-  const COMPONENT_COMMON* deflate()const;
+  COMMON_COMPONENT* deflate();
 };
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
+class EVAL_BM_MODEL : public EVAL_BM_ACTION_BASE {
+private:
+  std::string	_arglist;
+  COMMON_COMPONENT* _func;
+  explicit	EVAL_BM_MODEL(const EVAL_BM_MODEL& p);
+public:
+  explicit      EVAL_BM_MODEL(int c=0);
+		~EVAL_BM_MODEL()	{detach_common(&_func);}
+private: // override virtual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_MODEL(*this);}
+  const char*	name()const		{return modelname().c_str();}
+  bool		ac_too()const		{return true;}
+  void		parse(CS&);
+  void		print(OMSTREAM&)const;
+  void		expand();
+  void		tr_eval(ELEMENT*d)const
+		    {assert(_func); _func->tr_eval(d);}
+  void		ac_eval(ELEMENT*d)const
+		    {assert(_func); _func->ac_eval(d);}
+};
+/*--------------------------------------------------------------------------*/
 class EVAL_BM_COMPLEX : public EVAL_BM_ACTION_BASE {
 private:
   COMPLEX _value;
+  explicit	EVAL_BM_COMPLEX(const EVAL_BM_COMPLEX& p);
 public:
   explicit      EVAL_BM_COMPLEX(int c=0);
-  explicit	EVAL_BM_COMPLEX(const EVAL_BM_COMPLEX& p);
 		~EVAL_BM_COMPLEX()	{}
 private: // override virtual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_COMPLEX(*this);}
   const char*	name()const		{return "COMPLEX";}
   bool		ac_too()const		{return true;}
   void		parse(CS&);
@@ -100,11 +131,12 @@ private:
   double _tau2;  // fall time constant
   double _period;// repeat period
   double _end;	 // marks the end of the list
+  explicit	EVAL_BM_EXP(const EVAL_BM_EXP& p);
 public:
   explicit      EVAL_BM_EXP(int c=0);
-  explicit	EVAL_BM_EXP(const EVAL_BM_EXP& p);
 		~EVAL_BM_EXP()		{}
 private: // override vitrual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_EXP(*this);}
   const char*	name()const		{return "EXP";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -114,16 +146,19 @@ private: // override vitrual
 /*--------------------------------------------------------------------------*/
 class EVAL_BM_FIT : public EVAL_BM_ACTION_BASE {
 private:
-  int _order;
+  int	 _order;
   double _below;
   double _above;
+  double _delta;
+  int    _smooth;
   std::vector<std::pair<double,double> > _table;
-  SPLINE* _s;
+  SPLINE* _spline;
+  explicit	EVAL_BM_FIT(const EVAL_BM_FIT& p);
 public:
   explicit      EVAL_BM_FIT(int c=0);
-  explicit	EVAL_BM_FIT(const EVAL_BM_FIT& p);
 		~EVAL_BM_FIT();
 private: // override virtual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_FIT(*this);}
   const char*	name()const		{return "FIT";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -132,11 +167,13 @@ private: // override virtual
 };
 /*--------------------------------------------------------------------------*/
 class EVAL_BM_GENERATOR : public EVAL_BM_ACTION_BASE {
+private:
+  explicit	EVAL_BM_GENERATOR(const EVAL_BM_GENERATOR& p);
 public:
   explicit      EVAL_BM_GENERATOR(int c=0);
-  explicit	EVAL_BM_GENERATOR(const EVAL_BM_GENERATOR& p);
 		~EVAL_BM_GENERATOR()	{}
 private: // override virtual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_GENERATOR(*this);}
   const char*	name()const		{return "GENERATOR";}
   bool		ac_too()const		{return true;}
   void		parse(CS&);
@@ -151,11 +188,12 @@ private:
   double _min;
   bool   _abs;
   std::vector<double> _c;
+  explicit	EVAL_BM_POLY(const EVAL_BM_POLY& p);
 public:
   explicit      EVAL_BM_POLY(int c=0);
-  explicit	EVAL_BM_POLY(const EVAL_BM_POLY& p);
 		~EVAL_BM_POLY()		{}
 private: // override vitrual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_POLY(*this);}
   const char*	name()const		{return "POLY";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -168,12 +206,15 @@ private:
   double _max;
   double _min;
   bool   _abs;
+  bool	 _odd;
+  bool	 _even;
   std::vector<std::pair<double,double> > _table;
+  explicit	EVAL_BM_POSY(const EVAL_BM_POSY& p);
 public:
   explicit      EVAL_BM_POSY(int c=0);
-  explicit	EVAL_BM_POSY(const EVAL_BM_POSY& p);
 		~EVAL_BM_POSY()		{}
 private: // override vitrual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_POSY(*this);}
   const char*	name()const		{return "POSY";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -191,11 +232,12 @@ private:
   double _width;
   double _period;
   double _end;
+  explicit	EVAL_BM_PULSE(const EVAL_BM_PULSE& p);
 public:
   explicit      EVAL_BM_PULSE(int c=0);
-  explicit	EVAL_BM_PULSE(const EVAL_BM_PULSE& p);
 		~EVAL_BM_PULSE()	{}
 private: // override vitrual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_PULSE(*this);}
   const char*	name()const		{return "PULSE";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -208,11 +250,13 @@ private:
   double _delta;
   int    _smooth;
   std::vector<std::pair<double,double> > _table;
+  SPLINE* _spline;  
+  explicit	EVAL_BM_PWL(const EVAL_BM_PWL& p);
 public:
   explicit      EVAL_BM_PWL(int c=0);
-  explicit	EVAL_BM_PWL(const EVAL_BM_PWL& p);
 		~EVAL_BM_PWL()		{}
 private: // override virtual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_PWL(*this);}
   const char*	name()const		{return "PWL";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -228,11 +272,12 @@ private:
   double _modindex;
   double _signal;
   double _end;
+  explicit	EVAL_BM_SFFM(const EVAL_BM_SFFM& p);
 public:
   explicit      EVAL_BM_SFFM(int c=0);
-  explicit	EVAL_BM_SFFM(const EVAL_BM_SFFM& p);
 		~EVAL_BM_SFFM()		{}
 private: // override vitrual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_SFFM(*this);}
   const char*	name()const		{return "SFFM";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -248,11 +293,12 @@ private:
   double _delay;
   double _damping;
   double _end;
+  explicit	EVAL_BM_SIN(const EVAL_BM_SIN& p);
 public:
   explicit      EVAL_BM_SIN(int c=0);
-  explicit	EVAL_BM_SIN(const EVAL_BM_SIN& p);
 		~EVAL_BM_SIN()		{}
 private: // override vitrual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_SIN(*this);}
   const char*	name()const		{return "SIN";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -264,11 +310,12 @@ class EVAL_BM_TANH : public EVAL_BM_ACTION_BASE {
 private:
   double _gain;
   double _limit;
+  explicit	EVAL_BM_TANH(const EVAL_BM_TANH& p);
 public:
   explicit      EVAL_BM_TANH(int c=0);
-  explicit	EVAL_BM_TANH(const EVAL_BM_TANH& p);
 		~EVAL_BM_TANH()		{}
 private: // override virtual
+  COMMON_COMPONENT* clone()const	{return new EVAL_BM_TANH(*this);}
   const char*	name()const		{return "TANH";}
   bool		ac_too()const		{return false;}
   void		parse(CS&);
@@ -279,12 +326,13 @@ private: // override virtual
 class EVAL_BM_VALUE : public EVAL_BM_ACTION_BASE {
 private:
   double _value;
+  explicit	EVAL_BM_VALUE(const EVAL_BM_VALUE& p);
 public:
   explicit      EVAL_BM_VALUE(int c=0);
-  explicit	EVAL_BM_VALUE(const EVAL_BM_VALUE& p);
 		~EVAL_BM_VALUE()	{}
   double	value()const		{return _value;}
 private: // override virtual
+  COMMON_COMPONENT* clone()const {untested(); return new EVAL_BM_VALUE(*this);}
   const char*	name()const		{return "VALUE";}
   bool		ac_too()const		{return false;}
   void		print(OMSTREAM&)const;
