@@ -1,5 +1,7 @@
-/*$Id: bm_cond.cc,v 18.8 2000/07/26 09:26:27 al Exp $ -*- C++ -*-
+/*$Id: bm_cond.cc,v 19.20 2001/05/05 07:42:40 al Exp $ -*- C++ -*-
  * behavioral modeling conditionals
+ * The conditions refer to types of analysis, type SIM_MODE in mode.h.
+ * An array "_func" stores handles to commons specific to each mode.
  */
 #include "ap.h"
 #include "bm.h"
@@ -9,7 +11,7 @@ static EVAL_BM_VALUE func_zero(CC_STATIC);
 EVAL_BM_COND::EVAL_BM_COND(int c)
   :EVAL_BM_BASE(c)
 {
-  std::fill_n(_func, sCOUNT, static_cast<const COMPONENT_COMMON*>(0));
+  std::fill_n(_func, sCOUNT, static_cast<COMMON_COMPONENT*>(0));
   std::fill_n(_set, sCOUNT, false);
 }
 /*--------------------------------------------------------------------------*/
@@ -36,7 +38,7 @@ void EVAL_BM_COND::parse(CS& cmd)
   int here = cmd.cursor();
   cmd.reset().skipbl();
   bool is_source = cmd.match1("viVI") 
-    || (cmd.match('.') && (cmd.pmatch(".VSOurce") || cmd.pmatch(".ISOurce")));
+    || (cmd.match1('.') && (cmd.pmatch(".VSOurce") || cmd.pmatch(".ISOurce")));
   cmd.reset(here);
 
   do {
@@ -52,14 +54,19 @@ void EVAL_BM_COND::parse(CS& cmd)
     if (_set[mode]) {
       cmd.warn(bWARNING, "duplicate mode");
     }
-    EVAL_BM_ACTION_BASE* c = EVAL_BM_ACTION_BASE::parse_func_type(cmd);
+    COMMON_COMPONENT* c = EVAL_BM_ACTION_BASE::parse_func_type(cmd);
+
+    if (!c) {
+      c = new EVAL_BM_MODEL;
+    }
+
     {if (!c) {
       cmd.warn(bWARNING, "need function or value");
     }else{
-      if (is_source 
-	   && mode == sNONE
-	   && !_set[sDC]
-	   && dynamic_cast<EVAL_BM_VALUE*>(c)) {
+      if (is_source		// Spice compatibility
+	  && mode == sNONE	// for sources, no condition implies "DC"
+	  && !_set[sDC]
+	  && dynamic_cast<EVAL_BM_VALUE*>(c)) {
 	mode = sDC;
       }
       c->parse(cmd);
@@ -69,6 +76,7 @@ void EVAL_BM_COND::parse(CS& cmd)
     }}
   } while (cmd.more() && !cmd.stuck(&here));
   
+  // apply rules to determine states not explicitly specified
   if (!_func[sOP] && _set[sDC])    {attach_common(_func[sDC],  &(_func[sOP]));}
   if (!_func[sOP] && _set[sNONE])  {attach_common(_func[sNONE],&(_func[sOP]));}
   if (!_func[sOP] && _set[sTRAN])  {attach_common(_func[sTRAN],&(_func[sOP]));}
@@ -91,6 +99,10 @@ void EVAL_BM_COND::parse(CS& cmd)
   if (!_func[sAC] && _set[sNONE] && (!is_source || c->ac_too()))
 				   {attach_common(_func[sNONE],&(_func[sAC]));}
   if (!_func[sAC])		   {attach_common(&func_zero,  &(_func[sAC]));}
+  
+  for (int i = 1; i < sCOUNT; ++i) {
+    assert(_func[i]);
+  }
 }
 /*--------------------------------------------------------------------------*/
 void EVAL_BM_COND::print(OMSTREAM& where)const
@@ -106,9 +118,11 @@ void EVAL_BM_COND::print(OMSTREAM& where)const
   }
 }
 /*--------------------------------------------------------------------------*/
-const COMPONENT_COMMON* EVAL_BM_COND::deflate()const
+COMMON_COMPONENT* EVAL_BM_COND::deflate()
 {
-  for (int i=1; i<sCOUNT; ++i) {
+  // If all are the same, there is no use for the COND.
+  // Return the one thing that is attached, so the caller can replace it.
+  for (int i = 1; i < sCOUNT; ++i) {
     if (_func[i] != _func[sNONE]) {
       return this;
     }
