@@ -1,4 +1,4 @@
-/*$Id: c_file.cc,v 18.4 2000/07/09 05:58:31 al Exp $ -*- C++ -*-
+/*$Id: c_file.cc,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
  * log and > commands
  * log == commands log to a file
  * >   == all output to a file (redirect stdout)
@@ -25,28 +25,27 @@ static OMSTREAM mlog;		/* log file bitmap		*/
  */
 void CMD::logger(CS& cmd)
 {
-  untested();
   static std::list<FILE*> filestack;
 
-  {if (cmd.more()){			/* a file name .. open it */
+  {if (cmd.more()) {			/* a file name .. open it */
       const char *access = "w";
-      while (cmd.match('>')){
+      while (cmd.match1('>')) {
 	access = "a";
 	cmd.skip();
 	cmd.skipbl();
       }
       FILE* newfile = xopen(cmd,"",access);
-      if (newfile){
+      if (newfile) {
         filestack.push_back(newfile);
-	mlog |= OMSTREAM(newfile);
+	mlog.attach(newfile);
       }
   }else{				/* empty command -- close a file */
-    {if (filestack.empty()){
+    {if (filestack.empty()) {
       error(bWARNING, "no files open\n");
     }else{
       FILE* oldfile = filestack.back();
       filestack.pop_back();
-      mlog &= ~(OMSTREAM(oldfile));
+      mlog.detach(oldfile);
       fclose(oldfile);
     }}
   }}
@@ -61,30 +60,29 @@ void CMD::logger(CS& cmd)
  */
 void CMD::file(CS& cmd)
 {
-  untested();
   static std::list<FILE*> filestack;
   
-  {if (cmd.more()){			/* a file name .. open it */
+  {if (cmd.more()) {			/* a file name .. open it */
     const char* access = "w";
-    while (cmd.match('>')){
+    while (cmd.match1('>')) {
       access = "a";
       cmd.skip();
       cmd.skipbl();
     }
     FILE* newfile = xopen(cmd,"",access);
-    if (newfile){
+    if (newfile) {
       filestack.push_back(newfile);
-      mout        |= OMSTREAM(newfile);
-      IO::mstdout |= OMSTREAM(newfile);
+      mout.attach(newfile);
+      IO::mstdout.attach(newfile);
     }
   }else{				/* empty command -- close a file */
-    {if (filestack.empty()){
+    {if (filestack.empty()) {
       error(bWARNING, "no files open\n");
     }else{
       FILE* oldfile = filestack.back();
       filestack.pop_back();
-      mout        &= ~(OMSTREAM(oldfile));
-      IO::mstdout &= ~(OMSTREAM(oldfile));
+      mout.detach(oldfile);
+      IO::mstdout.detach(oldfile);
       fclose(oldfile);
     }}
   }}
@@ -98,12 +96,12 @@ char *getcmd(const char *prompt, char *buffer, int buflen)
 {
   pllocate();
   IO::mstdout << prompt << " \b";	/* prompt & flush buffer */
-  if (!fgets(buffer, buflen, stdin)){
+  if (!fgets(buffer, buflen, stdin)) {
     error(bEXIT, "EOF on stdin\n");
   }
-  (IO::mstdout&~mout) << '\r';		/* reset col counter */
+  all_except(IO::mstdout, mout) << '\r';		/* reset col counter */
   trim(buffer);
-  (mlog | mout) << buffer << '\n';
+  all_of(mlog, mout) << buffer << '\n';
   return buffer;
 }
 /*--------------------------------------------------------------------------*/
