@@ -1,7 +1,9 @@
-/*$Id: c_getckt.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: c_getckt.cc,v 19.22 2001/05/08 04:10:27 al Exp $ -*- C++ -*-
  * build, get, merge, "<" commands
  * process circuit files, and keyboard entry
  */
+#include "bmm_semi.h"
+#include "bmm_table.h"
 #include "d_admit.h"
 #include "d_cap.h"
 #include "d_cccs.h"
@@ -112,7 +114,7 @@ void CMD::merge(CS& cmd)
 void CMD::run(CS& cmd)
 {
   STATUS::get.reset().start();
-  while (cmd.match('<')){
+  while (cmd.match1('<')) {
     CS nil("");
     clear(nil);
     cmd.skip();
@@ -146,13 +148,13 @@ static void getmerge(CS& cmd)
   
   {
     std::string buffer(getlines(filen)); // title
-    if (buffer.empty()){
+    if (buffer.empty()) {
       untested();
       error(bWARNING, "empty circuit file\n");
     }
     head = buffer;
 
-    {if (!quiet){
+    {if (!quiet) {
       IO::mstdout << head << '\n';
     }else{
       untested();
@@ -160,19 +162,17 @@ static void getmerge(CS& cmd)
   }
   CARD_LIST::putbefore = CARD_LIST::fat_iterator(&(CARD_LIST::card_list),
 					    CARD_LIST::card_list.end());
-  for (;;){
+  for (;;) {
     std::string buffer(getlines(filen));
-    if (buffer.empty()){
+    if (buffer.empty()) {
       break;
     }
-    if (echoon){
-      untested();
+    if (echoon) {
       IO::mstdout << buffer << '\n';
     }
     CS cs(buffer);
     CARD* brh = parsebranch(cs, false);
-    if (liston  &&  exists(brh)){
-      untested();
+    if (liston  &&  exists(brh)) {
       brh->print(IO::mstdout, false);
     }
   }
@@ -184,13 +184,13 @@ static void getmerge(CS& cmd)
 static CARD *parsebranch(CS& cmd, bool alwaysdupcheck)
 {
   CARD_LIST::fat_iterator ci(CARD_LIST::putbefore);
-  if (OPT::dupcheck ||  alwaysdupcheck){
+  if (OPT::dupcheck ||  alwaysdupcheck) {
     CS buf(cmd);
     ci = findbranch(buf, ci.list());
   }
  
   CARD* brh = NULL;
-  {if (!ci.isend()){ // found one like it, reparse same one
+  {if (!ci.isend()) { // found one like it, reparse same one
     brh = *ci;
     error(bWARNING, "replacing [" + brh->long_label() + "]\n");
     brh->parse(cmd);
@@ -201,12 +201,12 @@ static CARD *parsebranch(CS& cmd, bool alwaysdupcheck)
      * even though parsing it (cparse) changed it.
      */
     brh = cparse(cmd);
-    if (exists(brh)){
+    if (exists(brh)) {
       before.list()->insert(before, brh);
     }
   }}
-  if (exists(brh)){
-    if (brh->is_device()){
+  if (exists(brh)) {
+    if (brh->is_device()) {
       SIM::uninit();
     }
   }
@@ -224,7 +224,7 @@ static CARD *cparse(CS& cmd)
   
   CARD* brh = NULL;
   char id_letter = toupper(cmd.peek());
-  switch (id_letter){
+  switch (id_letter) {
     case '\0':	/* nothing */			    break;
     case '.':	brh = do_dot(cmd);		    break;
     case '\'':
@@ -260,10 +260,10 @@ static CARD *cparse(CS& cmd)
     case 'Z':	cmd.warn(bWARNING, "illegal type"); break;
     default:	cmd.warn(bWARNING, "illegal type"); break;
   }
-  if (exists(brh)){
+  if (exists(brh)) {
     assert(brh);
     brh->parse(cmd);
-  }else if (brh){
+  }else if (brh) {
     unreachable();
     error(bWARNING, "internal error: branch has no type <%s>\n",
     	  cmd.fullstring());
@@ -278,7 +278,7 @@ static CARD* do_G(CS& cmd)
 {
   int here = cmd.cursor();
   CARD* brh = NULL;
-  {if (cmd.pscan("VC$$")){
+  {if (cmd.pscan("VC$$")) {
     if      (cmd.pmatch("CAP"))	brh = new DEV_VCCAP;
     else if (cmd.pmatch("G")) 	brh = new DEV_VCG;
     else if (cmd.pmatch("R")) 	brh = new DEV_VCR;
@@ -326,15 +326,18 @@ static CARD* do_model(CS& cmd)
 {
   cmd.skiparg(); // skip name
   if      (cmd.pmatch("D"    )) return new MODEL_DIODE;
-  else if (cmd.pmatch("NPn"  )) cmd.warn(bWARNING, "not implemented");
-  else if (cmd.pmatch("PNp"  )) cmd.warn(bWARNING, "not implemented");
-  else if (cmd.pmatch("NJf"  )) cmd.warn(bWARNING, "not implemented");
-  else if (cmd.pmatch("PJf"  )) cmd.warn(bWARNING, "not implemented");
-  else if (cmd.pmatch("NMos" )) return do_mos_model(cmd);
-  else if (cmd.pmatch("PMos" )) return do_mos_model(cmd);
+  else if (cmd.pmatch("NPN"  )) cmd.warn(bWARNING, "not implemented");
+  else if (cmd.pmatch("PNP"  )) cmd.warn(bWARNING, "not implemented");
+  else if (cmd.pmatch("NJF"  )) cmd.warn(bWARNING, "not implemented");
+  else if (cmd.pmatch("PJF"  )) cmd.warn(bWARNING, "not implemented");
+  else if (cmd.pmatch("NMOS" )) return do_mos_model(cmd);
+  else if (cmd.pmatch("PMOS" )) return do_mos_model(cmd);
   else if (cmd.pmatch("Logic")) return new MODEL_LOGIC;
   else if (cmd.pmatch("SW"   )) return new MODEL_SWITCH;
   else if (cmd.pmatch("CSW"  )) return new MODEL_SWITCH;
+  else if (cmd.pmatch("Res"  )) return new MODEL_SEMI_RESISTOR;
+  else if (cmd.pmatch("Cap"  )) return new MODEL_SEMI_CAPACITOR;
+  else if (cmd.pmatch("TABLE")) return new MODEL_TABLE;
   else				cmd.warn(bWARNING, "illegal type");
   return NULL;
 }
@@ -344,13 +347,9 @@ static CARD* do_mos_model(CS& cmd)
   /* already parsed to know it is either NMos or PMos */
   cmd.skiplparen();
   int level = 1;
-  {if (cmd.pscan("LEvel")){
-    cmd >> level;
-  }else{
-    cmd.warn(bWARNING, "no level specified, using 1");
-    level = 1;
-  }}
-  switch (level){
+  scan_get(cmd, "LEvel", &level) 
+    || cmd.warn(bWARNING, "no level specified, using 1");
+  switch (level) {
   default:
   case 1: return new MODEL_MOS1;
   case 2: return new MODEL_MOS2;
