@@ -1,4 +1,4 @@
-/*$Id: c_list.cc,v 17.10 2000/04/04 06:30:02 al Exp $ -*- C++ -*-
+/*$Id: c_list.cc,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
  * list and save commands.
  * save is list with direction to file
  */
@@ -20,7 +20,7 @@ void CMD::list(CS& cmd)
 void CMD::save(CS& cmd)
 {
   cmd.reset();			/* back up to beginning of input line */
-  OMSTREAM out = IO::mstdout;
+  OMSTREAM out; // = IO::mstdout;
   list_save(cmd, *outset(cmd,&out));
 }
 /*--------------------------------------------------------------------------*/
@@ -38,7 +38,7 @@ static void list_save(CS& cmd, OMSTREAM out)
     break;
   }
 
-  (out & ~IO::mstdout) << head << '\n';
+  all_except(out, IO::mstdout) << head << '\n';
 
   {if (cmd.end()){			/* no args: list all		    */
     for (CARD_LIST::const_iterator
@@ -52,7 +52,7 @@ static void list_save(CS& cmd, OMSTREAM out)
       cmd.warn(bERROR, "can't find");
     }
     
-    {if (cmd.match('-')){		/* there is a dash:  a range	    */
+    {if (cmd.match1('-')){		/* there is a dash:  a range	    */
       cmd.skip();
       CARD_LIST::fat_iterator stop = ci;
       stop = findbranch(cmd, ++stop);
