@@ -1,4 +1,4 @@
-/*$Id: constant.h,v 18.9 2000/08/16 08:11:43 al Exp $ -*- C++ -*-
+/*$Id: constant.h,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * defined constants for just about everything
  */
 #ifndef CONSTANT_H
@@ -33,21 +33,12 @@ const double ICM2M2 = 1e4;		/* inverse  ...........  squared */
 const double ICM2M3 = 1e6;		/* inverse  ...........  cubed   */
 const double MICRON2METER = 1e-6;	/*	microns to meters	 */
 
-#ifdef BROKEN_CONST_FOLD
-#define BIGBIG    ( (DBL_MAX)*(.9247958))
-#define OVERDUE   (-(DBL_MAX)*(.9347958))
-#define NEVER     ( (DBL_MAX)*(.9447958))
-#define NOT_INPUT (-(DBL_MAX)*(.9547658))
-#define NOT_VALID (-(DBL_MAX)*(.9647958))
-#define LINEAR    (-(DBL_MAX)*(.9747958))
-#else
 const double BIGBIG    =  (DBL_MAX)*(.9247958);	/* unlikely number	  */
 const double OVERDUE   = -(DBL_MAX)*(.9347958);	/* unlikely number	  */
 const double NEVER     =  (DBL_MAX)*(.9447958);	/* unlikely number	  */
 const double NOT_INPUT = -(DBL_MAX)*(.9547658);	/* unlikely number	  */
 const double NOT_VALID = -(DBL_MAX)*(.9647958);	/* unlikely number	  */
 const double LINEAR    = -(DBL_MAX)*(.9747958);	/* unlikely number	  */
-#endif
 const double VOLTMIN   =  1.0e-50;
 const double PWRMIN    =  1.0e-100;
 
