@@ -1,4 +1,4 @@
-/*$Id: d_coil.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: d_coil.cc,v 19.20 2001/05/05 07:42:40 al Exp $ -*- C++ -*-
  * inductors
  * y.x = amps,  y.f0 = flux, ev = y.f1 = henrys
  * m.x = volts, m.c0 = amps, acg = m.c1 = mhos.
@@ -131,6 +131,15 @@ void DEV_MUTUAL_L::expand()
   assert(!constant()); /* because of integration */
 }
 /*--------------------------------------------------------------------------*/
+void DEV_INDUCTANCE::map_nodes()
+{
+  {if (subckt().exists()) {
+    subckt().map_nodes();
+  }else{
+  }}
+  COMPONENT::map_nodes();
+}
+/*--------------------------------------------------------------------------*/
 void DEV_INDUCTANCE::precalc()
 {
   {if (subckt().exists()) {
@@ -225,6 +234,7 @@ bool DEV_INDUCTANCE::do_tr()
 	untested();
 	error(bPICKY, long_label() + ": short circuit\n");
 	_y0.f1 = OPT::shortckt;
+	set_converged(conv_check());
       }
     }else{
       _m0.x = _n[OUT1].v0() - _n[OUT2].v0();
