@@ -1,4 +1,4 @@
-/*$Id: d_coil.h,v 17.22 2000/05/12 10:31:53 al Exp $ -*- C++ -*-
+/*$Id: d_coil.h,v 19.3 2000/11/30 01:09:48 al Exp $ -*- C++ -*-
  * Inductance (L) component
  */
 #ifndef D_COIL_H
@@ -19,6 +19,7 @@ private: // override virtual
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
   //void   expand();		//CARD/nothing
+  void	   map_nodes();
   void     precalc();
 
   void	   dc_begin();
@@ -62,6 +63,7 @@ private: // override virtual
   void	   parse(CS&);
   void	   print(OMSTREAM& where, int detail)const;
   void	   expand();
+  void	   map_nodes()		{}
   //void   precalc();		//CARD/nothing
 
   //void   dc_begin();		//CARD/nothing
