@@ -1,4 +1,4 @@
-/*$Id: d_logic.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: d_logic.cc,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * logic model and device.
  * netlist syntax:
  * device:  mxxxx  out gnd vdd in1 in2 ... family gatetype
@@ -10,7 +10,7 @@
 /*--------------------------------------------------------------------------*/
 extern NODE* nstat;
 int DEV_LOGIC::_count = 0;
-int LOGIC_COMMON::_count = -1;
+int COMMON_LOGIC::_count = -1;
 static LOGIC_NONE Default_LOGIC(CC_STATIC);
 /*--------------------------------------------------------------------------*/
 DEV_LOGIC::DEV_LOGIC()
@@ -54,7 +54,7 @@ void DEV_LOGIC::parse(CS& cmd)
   incount -= BEGIN_IN;
   std::string modelname = cmd.ctos(TOKENTERM);
 
-  LOGIC_COMMON* c = 0;
+  COMMON_LOGIC* c = 0;
   {if     (cmd.pmatch("AND" )) {c = new LOGIC_AND;}
   else if (cmd.pmatch("NAND")) {c = new LOGIC_NAND;}
   else if (cmd.pmatch("OR"  )) {c = new LOGIC_OR;}
@@ -71,7 +71,7 @@ void DEV_LOGIC::parse(CS& cmd)
 /*--------------------------------------------------------------------------*/
 void DEV_LOGIC::print(OMSTREAM& where, int)const
 {
-  const LOGIC_COMMON* c = prechecked_cast<const LOGIC_COMMON*>(common());
+  const COMMON_LOGIC* c = prechecked_cast<const COMMON_LOGIC*>(common());
   assert(c);
   where << short_label();
   printnodes(where, PORTSPERGATE);
@@ -80,7 +80,7 @@ void DEV_LOGIC::print(OMSTREAM& where, int)const
 /*--------------------------------------------------------------------------*/
 void DEV_LOGIC::expand()
 {
-  const LOGIC_COMMON* c = prechecked_cast<const LOGIC_COMMON*>(common());
+  const COMMON_LOGIC* c = prechecked_cast<const COMMON_LOGIC*>(common());
   assert(c);
   const MODEL_LOGIC* m = dynamic_cast<const MODEL_LOGIC*>(attach_model());
   if (!m){
@@ -229,7 +229,7 @@ bool DEV_LOGIC::tr_eval_digital()
   case SIM::pNONE:	unreachable();		break;
   }
   
-  const LOGIC_COMMON* c = prechecked_cast<const LOGIC_COMMON*>(common());
+  const COMMON_LOGIC* c = prechecked_cast<const COMMON_LOGIC*>(common());
   assert(c);
   const MODEL_LOGIC* m = prechecked_cast<const MODEL_LOGIC*>(c->model());
   assert(m);
@@ -286,7 +286,7 @@ double DEV_LOGIC::tr_review()
 void DEV_LOGIC::tr_accept()
 {
   assert(_gatemode == moDIGITAL || _gatemode == moANALOG);
-  const LOGIC_COMMON* c = prechecked_cast<const LOGIC_COMMON*>(common());
+  const COMMON_LOGIC* c = prechecked_cast<const COMMON_LOGIC*>(common());
   assert(c);
   const MODEL_LOGIC* m = prechecked_cast<const MODEL_LOGIC*>(c->model());
   assert(m);
@@ -410,4 +410,16 @@ XPROBE DEV_LOGIC::ac_probe_ext(CS& what)const
   return nstat[_n[OUTNODE].m].ac_probe_ext(what);
 }
 /*--------------------------------------------------------------------------*/
+bool COMMON_LOGIC::operator==(const COMMON_COMPONENT& x)const
+{
+  const COMMON_LOGIC* p = dynamic_cast<const COMMON_LOGIC*>(&x);
+  bool rv = p
+    && incount == p->incount
+    && is_equal(x);
+  if (rv) {
+    untested();
+  }
+  return rv;
+}
+/*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
