@@ -1,4 +1,4 @@
-/*$Id: d_logic.h,v 17.21 2000/05/02 09:32:08 al Exp $ -*- C++ -*-
+/*$Id: d_logic.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * data structures and defaults for logic model.
  */
 #ifndef D_LOGIC_H
@@ -59,6 +59,7 @@ private: // override virtuals
   void	   parse(CS&);
   void	   print(OMSTREAM&,int)const;
   void	   expand();
+  void	   map_nodes()	{COMPONENT::map_nodes(); subckt().map_nodes();}
   void	   precalc();
 
   void	   dc_begin();
@@ -102,14 +103,15 @@ private:
   enum {OUTNODE=0, GND_NODE=1, PWR_NODE=2, ENABLE=3, BEGIN_IN=4}; /* node labels */
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_COMMON : public COMPONENT_COMMON {
+class COMMON_LOGIC : public COMMON_COMPONENT {
 protected:
-  explicit	LOGIC_COMMON(int c=0)
-    :COMPONENT_COMMON(c), incount(0) {++_count;}
-  explicit	LOGIC_COMMON(const LOGIC_COMMON& p)
-    :COMPONENT_COMMON(p), incount(p.incount) {untested(); ++_count;}
+  explicit	COMMON_LOGIC(int c=0)
+    :COMMON_COMPONENT(c), incount(0) {++_count;}
+  explicit	COMMON_LOGIC(const COMMON_LOGIC& p)
+    :COMMON_COMPONENT(p), incount(p.incount) {untested(); ++_count;}
 public:
-		~LOGIC_COMMON()			{--_count;}
+		~COMMON_LOGIC()			{--_count;}
+  bool operator==(const COMMON_COMPONENT&)const;
   static  int	count()				{return _count;}
   virtual LOGICVAL logic_eval(NODE**)const	= 0;
 public:
@@ -118,63 +120,77 @@ protected:
   static int	_count;
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_AND : public LOGIC_COMMON {
+class LOGIC_AND : public COMMON_LOGIC {
+private:
+  explicit LOGIC_AND(const LOGIC_AND& p) :COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_AND(*this);}
 public:
-  explicit LOGIC_AND(int c=0)		  :LOGIC_COMMON(c) {untested();}
-  explicit LOGIC_AND(const LOGIC_AND& p) :LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_AND(int c=0)		  :COMMON_LOGIC(c) {untested();}
   LOGICVAL logic_eval(NODE** ns)const {untested(); LOGICVAL out(lvSTABLE1);
     for (int ii=0; ii<incount; ++ii){out &= ns[ii]->lv();} return out;}
   virtual const char* name()const	  {return "and";}
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_NAND : public LOGIC_COMMON {
+class LOGIC_NAND : public COMMON_LOGIC {
+private:
+  explicit LOGIC_NAND(const LOGIC_NAND&p):COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_NAND(*this);}
 public:
-  explicit LOGIC_NAND(int c=0)		  :LOGIC_COMMON(c) {untested();}
-  explicit LOGIC_NAND(const LOGIC_NAND&p):LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_NAND(int c=0)		  :COMMON_LOGIC(c) {untested();}
   LOGICVAL logic_eval(NODE** ns)const {untested(); LOGICVAL out(lvSTABLE1);
     for (int ii=0; ii<incount; ++ii){out &= ns[ii]->lv();} return ~out;}
   virtual const char* name()const	  {return "nand";}
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_OR : public LOGIC_COMMON {
+class LOGIC_OR : public COMMON_LOGIC {
+private:
+  explicit LOGIC_OR(const LOGIC_OR& p)	 :COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_OR(*this);}
 public:
-  explicit LOGIC_OR(int c=0)		  :LOGIC_COMMON(c) {untested();}
-  explicit LOGIC_OR(const LOGIC_OR& p)	 :LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_OR(int c=0)		  :COMMON_LOGIC(c) {untested();}
   LOGICVAL logic_eval(NODE** ns)const {untested(); LOGICVAL out(lvSTABLE0);
     for (int ii=0; ii<incount; ++ii){out |= ns[ii]->lv();} return out;}
   virtual const char* name()const	  {return "or";}
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_NOR : public LOGIC_COMMON {
+class LOGIC_NOR : public COMMON_LOGIC {
+private:
+  explicit LOGIC_NOR(const LOGIC_NOR& p) :COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_NOR(*this);}
 public:
-  explicit LOGIC_NOR(int c=0)		  :LOGIC_COMMON(c) {untested();}
-  explicit LOGIC_NOR(const LOGIC_NOR& p) :LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_NOR(int c=0)		  :COMMON_LOGIC(c) {untested();}
   LOGICVAL logic_eval(NODE** ns)const {untested(); LOGICVAL out(lvSTABLE0);
     for (int ii=0; ii<incount; ++ii){out |= ns[ii]->lv();} return ~out;}
   virtual const char* name()const	  {return "nor";}
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_XOR : public LOGIC_COMMON {
+class LOGIC_XOR : public COMMON_LOGIC {
+private:
+  explicit LOGIC_XOR(const LOGIC_XOR& p) :COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_XOR(*this);}
 public:
-  explicit LOGIC_XOR(int c=0)		  :LOGIC_COMMON(c) {untested();}
-  explicit LOGIC_XOR(const LOGIC_XOR& p) :LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_XOR(int c=0)		  :COMMON_LOGIC(c) {untested();}
   LOGICVAL logic_eval(NODE** ns)const
     {untested(); return ns[0]->lv() ^ ns[1]->lv();}
   virtual const char* name()const	  {return "xor";}
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_INV : public LOGIC_COMMON {
+class LOGIC_INV : public COMMON_LOGIC {
+private:
+  explicit LOGIC_INV(const LOGIC_INV& p) :COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_INV(*this);}
 public:
-  explicit LOGIC_INV(int c=0)		  :LOGIC_COMMON(c) {}
-  explicit LOGIC_INV(const LOGIC_INV& p) :LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_INV(int c=0)		  :COMMON_LOGIC(c) {}
   LOGICVAL logic_eval(NODE** ns)const	  {return ~ns[0]->lv();}
   virtual const char* name()const	  {return "inv";}
 };
 /*--------------------------------------------------------------------------*/
-class LOGIC_NONE : public LOGIC_COMMON {
+class LOGIC_NONE : public COMMON_LOGIC {
+private:
+  explicit LOGIC_NONE(const LOGIC_NONE&p):COMMON_LOGIC(p){untested();++_count;}
+  COMMON_COMPONENT* clone()const {untested(); return new LOGIC_NONE(*this);}
 public:
-  explicit LOGIC_NONE(int c=0)		  :LOGIC_COMMON(c) {}
-  explicit LOGIC_NONE(const LOGIC_NONE&p):LOGIC_COMMON(p){untested();++_count;}
+  explicit LOGIC_NONE(int c=0)		  :COMMON_LOGIC(c) {}
   LOGICVAL logic_eval(NODE**)const	  {untested(); return lvUNKNOWN;}
   virtual const char* name()const	  {return "error";}
 };
