@@ -1,4 +1,4 @@
-/*$Id: d_mos.cc,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: d_mos.cc,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * mos device basics
  * netlist syntax:
  * device:  mxxxx d g s b mname <device args> <model card args>
@@ -12,15 +12,15 @@
 #include "d_mos_base.h"
 //#include "d_mos.h" already included
 /*--------------------------------------------------------------------------*/
-int MOS_COMMON::_count = -1;
+int COMMON_MOS::_count = -1;
 int DEV_MOS::_count = 0;
 static EVAL_MOS_Cgb Eval_Cgb(CC_STATIC);
 static EVAL_MOS_Cgd Eval_Cgd(CC_STATIC);
 static EVAL_MOS_Cgs Eval_Cgs(CC_STATIC);
-static MOS_COMMON Default_MOS(CC_STATIC);
+static COMMON_MOS Default_MOS(CC_STATIC);
 /*--------------------------------------------------------------------------*/
-MOS_COMMON::MOS_COMMON(int c)
-  :COMPONENT_COMMON(c),
+COMMON_MOS::COMMON_MOS(int c)
+  :COMMON_COMPONENT(c),
    sdp(0),
    lo(NOT_INPUT),
    wo(NOT_INPUT),
@@ -32,8 +32,8 @@ MOS_COMMON::MOS_COMMON(int c)
    nrs(1.0),
    off(false),
    icset(false),
-   sb(c),
-   db(c)
+   _sb(0),
+   _db(0)
 {
   for (int i = 0;  i < mNUM_INIT_COND;  i++){
     ic[i] = 0.;
@@ -42,8 +42,8 @@ MOS_COMMON::MOS_COMMON(int c)
   /* not all is initialized.  remainder filled in by expand */
 }
 /*--------------------------------------------------------------------------*/
-MOS_COMMON::MOS_COMMON(const MOS_COMMON& p)
-  :COMPONENT_COMMON(p),
+COMMON_MOS::COMMON_MOS(const COMMON_MOS& p)
+  :COMMON_COMPONENT(p),
    sdp(0),
    lo(p.lo),
    wo(p.wo),
@@ -55,9 +55,11 @@ MOS_COMMON::MOS_COMMON(const MOS_COMMON& p)
    nrs(p.nrs),
    off(p.off),
    icset(p.icset),
-   sb(p.sb, CC_STATIC),
-   db(p.db, CC_STATIC)
+   _sb(0),
+   _db(0)
 {
+  attach_common(p._sb, &_sb);
+  attach_common(p._db, &_db);
   for (int i = 0;  i < mNUM_INIT_COND;  i++){
     ic[i] = 0.;
   }
@@ -65,20 +67,51 @@ MOS_COMMON::MOS_COMMON(const MOS_COMMON& p)
   /* not all is initialized.  remainder filled in by expand */
 }
 /*--------------------------------------------------------------------------*/
-MOS_COMMON::~MOS_COMMON()
+COMMON_MOS::~COMMON_MOS()
 {
+  detach_common(&_db);
+  detach_common(&_sb);
   --_count;
   delete sdp;
 }
 /*--------------------------------------------------------------------------*/
-void MOS_COMMON::parse(CS& cmd)
+bool COMMON_MOS::operator==(const COMMON_COMPONENT&)const
+{
+#if 0
+  const COMMON_DIODE* p = dynamic_cast<const COMMON_DIODE*>(&x);
+  bool rv = p
+    && area == p->area
+    && perim == p->perim
+    && off == p->off
+    && ic == p->ic
+    && is_equal(x);
+  if (0) {
+    untested();
+    assert(is == p->is);
+    assert(rs == p->rs);
+    assert(cj == p->cj);
+    assert(cjsw == p->cjsw);
+    assert(gparallel == p->gparallel);
+    assert(calc_is == p->calc_is);
+    assert(calc_rs == p->calc_rs);
+    assert(calc_cj == p->calc_cj);
+    assert(calc_cjsw == p->calc_cjsw);
+    assert(calc_gparallel == p->calc_gparallel);
+  }else{
+    //untested();
+  }
+#endif
+  return false;
+}
+/*--------------------------------------------------------------------------*/
+void COMMON_MOS::parse(CS& cmd)
 {
   assert(!has_model());
 
   parse_modelname(cmd);
   if (cmd.is_pfloat()){				/* accept W/L notation for */
     wo = cmd.ctopf() * MICRON2METER;		/* dimensions (microns)    */
-    {if (cmd.match('/')){
+    {if (cmd.match1('/')){
       untested();
       cmd.skip();
       lo = cmd.ctopf() * MICRON2METER;
@@ -100,7 +133,7 @@ void MOS_COMMON::parse(CS& cmd)
   cmd.check(bWARNING, "what's this?");
 }
 /*--------------------------------------------------------------------------*/
-void MOS_COMMON::print(OMSTREAM& where)const
+void COMMON_MOS::print(OMSTREAM& where)const
 {
   where << "  " << modelname();
 
@@ -128,7 +161,7 @@ void MOS_COMMON::print(OMSTREAM& where)const
   where << '\n';
 }
 /*--------------------------------------------------------------------------*/
-const MODEL_MOS_BASE* MOS_COMMON::expand()
+void COMMON_MOS::expand()
 {
   const MODEL_MOS_BASE* m=dynamic_cast<const MODEL_MOS_BASE*>(attach_model());
   if (!m){
@@ -144,25 +177,27 @@ const MODEL_MOS_BASE* MOS_COMMON::expand()
   const SDP_MOS_BASE* b = dynamic_cast<const SDP_MOS_BASE*>(sdp);
   assert(b);
 
-  db.set_modelname(modelname());
-  db.area = b->ad;
-  db.perim = pd;
-  db.is = b->idsat;
-  db.cj = m->cbd;	/* if NOT_INPUT diode will calculate it */
-  db.cjsw = NOT_INPUT;
-  db.attach(model());
-  db.off = true;
+  COMMON_DIODE* db = new COMMON_DIODE;
+  db->set_modelname(modelname());
+  db->area = b->ad;
+  db->perim = pd;
+  db->is_raw = b->idsat;
+  db->cj_raw = m->cbd;	/* if NOT_INPUT diode will calculate it */
+  db->cjsw_raw = NOT_INPUT;
+  db->attach(model());
+  db->off = true;
+  attach_common(db, &_db);
 
-  sb.set_modelname(modelname());
-  sb.area = b->as;
-  sb.perim = ps;
-  sb.is = b->issat;
-  sb.cj = m->cbs;	/* if NOT_INPUT diode will calculate it */
-  sb.cjsw = NOT_INPUT;
-  sb.attach(model());
-  sb.off = true;
-
-  return m;
+  COMMON_DIODE* sb = new COMMON_DIODE;
+  sb->set_modelname(modelname());
+  sb->area = b->as;
+  sb->perim = ps;
+  sb->is_raw = b->issat;
+  sb->cj_raw = m->cbs;	/* if NOT_INPUT diode will calculate it */
+  sb->cjsw_raw = NOT_INPUT;
+  sb->attach(model());
+  sb->off = true;
+  attach_common(sb, &_sb);
 }
 /*--------------------------------------------------------------------------*/
 DEV_MOS::DEV_MOS()
@@ -200,9 +235,8 @@ DEV_MOS::DEV_MOS(const DEV_MOS& p):BASE_SUBCKT(p)
 /*--------------------------------------------------------------------------*/
 void DEV_MOS::parse(CS& cmd)
 {
-  const MOS_COMMON* cc = prechecked_cast<const MOS_COMMON*>(common());
-  assert(cc);
-  MOS_COMMON* c = new MOS_COMMON(*cc);
+  assert(has_common());
+  COMMON_MOS* c = prechecked_cast<COMMON_MOS*>(common()->clone());
   assert(c);
   
   parse_Label(cmd);
@@ -213,7 +247,7 @@ void DEV_MOS::parse(CS& cmd)
 /*--------------------------------------------------------------------------*/
 void DEV_MOS::print(OMSTREAM& where, int)const
 {
-  const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(common());
+  const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(common());
   assert(c);
 
   where << short_label();
@@ -223,7 +257,7 @@ void DEV_MOS::print(OMSTREAM& where, int)const
 /*--------------------------------------------------------------------------*/
 double DEV_MOS::tr_probe_num(CS& cmd)const
 {
-  const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(common());
+  const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(common());
   assert(c);
   const SDP_MOS_BASE* b = prechecked_cast<const SDP_MOS_BASE*>(c->sdp);
   assert(b);
@@ -409,7 +443,7 @@ bool DEV_MOS::tr_needs_eval()
   }else if (!converged()){
     return true;
   }else{
-    const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(common());
+    const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(common());
     assert(c);
     const MODEL_MOS_BASE* m=prechecked_cast<const MODEL_MOS_BASE*>(c->model());
     assert(m);
@@ -421,7 +455,7 @@ bool DEV_MOS::tr_needs_eval()
 	     && conchk(vbs, polarity*(nBULK.v0()-eff_source.v0()),OPT::vntol));
   }}
 }
-/* on STATUS::iter[iSTEP] ..............
+/* In an older version, it was necessary to check STATUS::iter[iSTEP].
  * This forces nobypass on the first iteration of a new time step.
  * It hides a BUG, probably in review.
  * If an entire time step is bypassed, review doesn't realize it is ok
@@ -429,20 +463,19 @@ bool DEV_MOS::tr_needs_eval()
  * numbers are ok.
  * The reason this is necessary is that a capacitor inside a mosfet may
  * need evaluation (integration) even if the whole device is bypassed.
+ * I believe this is done in the queue mechanism, but I am leaving the
+ * comment here as a pointer to a possible future problem.
  */
 /*--------------------------------------------------------------------------*/
 bool DEV_MOS::do_tr()
 {
-  const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(common());
+  const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(common());
   assert(c);
   const MODEL_MOS_BASE* m = prechecked_cast<const MODEL_MOS_BASE*>(c->model());
   assert(m);
   assert(subckt().exists());
 
   double Vds, Vgs, Vbs;
-  
-  sourcenode.map();	/* BUG:: why is this here??.... */
-  drainnode.map();	/* because these nodes get missed in the usual map */
 
   bool was_cutoff = cutoff;
   bool was_subthreshold = subthreshold;
@@ -624,11 +657,10 @@ void DEV_MOS::limit_mos(double Vds, double Vgs, double Vbs)
 /*--------------------------------------------------------------------------*/
 void DEV_MOS::expand()
 {
-  const MOS_COMMON* cc = prechecked_cast<const MOS_COMMON*>(common());
-  assert(cc);
-  MOS_COMMON* c = const_cast<MOS_COMMON*>(cc);
+  COMMON_MOS* c = prechecked_cast<COMMON_MOS*>(mutable_common());
   assert(c);
-  const MODEL_MOS_BASE* m = c->expand();
+  c->expand();
+  const MODEL_MOS_BASE* m =prechecked_cast<const MODEL_MOS_BASE*>(c->model());
   assert(m);
   const SDP_MOS_BASE* b = prechecked_cast<const SDP_MOS_BASE*>(c->sdp);
   assert(b);
@@ -694,10 +726,10 @@ void DEV_MOS::expand()
     }
     switch (m->polarity){
     case pN:
-      Ddb->set("Ddb", this, &(c->db), 0., nBULK, drainnode);
+      Ddb->set("Ddb", this, c->_db, 0., nBULK, drainnode);
       break;
     case pP:
-      Ddb->set("Ddb", this, &(c->db), 0., drainnode, nBULK);
+      Ddb->set("Ddb", this, c->_db, 0., drainnode, nBULK);
       break;
     }
   }else{
@@ -715,10 +747,10 @@ void DEV_MOS::expand()
     }
     switch (m->polarity){
     case pN:
-      Dsb->set("Dsb", this, &(c->sb), 0., nBULK, sourcenode);
+      Dsb->set("Dsb", this, c->_sb, 0., nBULK, sourcenode);
       break;
     case pP:
-      Dsb->set("Dsb", this, &(c->sb), 0., sourcenode, nBULK);
+      Dsb->set("Dsb", this, c->_sb, 0., sourcenode, nBULK);
       break;
     }
   }else{
@@ -739,7 +771,6 @@ void DEV_MOS::expand()
     if (Cgs){
       subckt().erase(Cgs);
       Cgs = NULL;
-      untested();
     }
   }}
 
@@ -753,7 +784,6 @@ void DEV_MOS::expand()
     if (Cgd){
       subckt().erase(Cgd);
       Cgd = NULL;
-      untested();
     }
   }}
 
@@ -767,7 +797,6 @@ void DEV_MOS::expand()
     {if (Cgb){
       subckt().erase(Cgb);
       Cgb = NULL;
-      untested();
     }else{
       untested();
     }}
@@ -790,7 +819,7 @@ void DEV_MOS::expand()
   }
 
   assert(subckt().exists());
-  subckt().expand();
+  BASE_SUBCKT::expand();
   subckt().set_slave();
 
   assert(!constant()); /* because it is nonlinear */
