@@ -1,14 +1,15 @@
-/*$Id: d_mos.h,v 17.23 2000/05/26 08:01:37 al Exp $ -*- C++ -*-
+/*$Id: d_mos.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * data structures and defaults for mos model.
  * internal units all mks (meters)
  * but some user input parameters are in cm.
  */
 #ifndef D_MOS_H
 #define D_MOS_H
+#include "e_subckt.h"
 #include "d_diode.h"
 /*--------------------------------------------------------------------------*/
 class DEV_MOS;			/* this file */
-class MOS_COMMON;
+class COMMON_MOS;
 class EVAL_MOS_Cgb;
 class EVAL_MOS_Cgd;
 class EVAL_MOS_Cgs;
@@ -35,13 +36,14 @@ private: // override virtual
   void	    parse(CS&);
   void	    print(OMSTREAM&,int)const;
   void	    expand();
-  //void    precalc();		//BASE_SUBCKT, wrong
-
+  void	    map_nodes()
+		{sourcenode.map();drainnode.map();BASE_SUBCKT::map_nodes();}
+  //void    precalc();		//BASE_SUBCKT
   //void    dc_begin();		//BASE_SUBCKT
   //void    tr_begin();		//BASE_SUBCKT
   //void    tr_restore();	//BASE_SUBCKT
-  void      dc_advance()	{set_not_converged(); subckt().dc_advance();}
-  void      tr_advance()	{set_not_converged(); subckt().tr_advance();}
+  void      dc_advance()      {set_not_converged(); BASE_SUBCKT::dc_advance();}
+  void      tr_advance()      {set_not_converged(); BASE_SUBCKT::tr_advance();}
   bool	    tr_needs_eval();
   void	    tr_queue_eval()	{if(tr_needs_eval()){q_eval();}}
   bool	    do_tr();
@@ -138,14 +140,17 @@ public:
   static int _count;
 };
 /*--------------------------------------------------------------------------*/
-class MOS_COMMON : public COMPONENT_COMMON {
+class COMMON_MOS : public COMMON_COMPONENT {
+private:
+  explicit	COMMON_MOS(const COMMON_MOS& p);
 public:
-  explicit	MOS_COMMON(int c=0);
-  explicit	MOS_COMMON(const MOS_COMMON& p);
-		~MOS_COMMON();
+  explicit	COMMON_MOS(int c=0);
+		~COMMON_MOS();
+  bool		operator==(const COMMON_COMPONENT&)const;
+  COMMON_COMPONENT* clone()const	{return new COMMON_MOS(*this);}
   void		parse(CS&);
   void		print(OMSTREAM&)const;
-  const MODEL_MOS_BASE* expand();
+  void		expand();
   const char*	name()const		{untested(); return "mos";}
   static int	count()			{return _count;}
 public:
@@ -162,42 +167,48 @@ public:
   int	   off;		/* off flag				*/
   int	   icset;	/* flag: initial conditions set		*/
    			/* up to here initialized		*/
-  DIODE_COMMON sb;
-  DIODE_COMMON db;
+  COMMON_COMPONENT* _sb;
+  COMMON_COMPONENT* _db;
 private:
   static int _count;
 };
 /*--------------------------------------------------------------------------*/
-class EVAL_MOS_Cgb : public COMPONENT_COMMON {
+class EVAL_MOS_Cgb : public COMMON_COMPONENT {
 private:
   explicit EVAL_MOS_Cgb(const EVAL_MOS_Cgb& p) 
-    :COMPONENT_COMMON(p) {unreachable();}
+    :COMMON_COMPONENT(p) {unreachable();}
 public:
-  explicit EVAL_MOS_Cgb(int c=0) :COMPONENT_COMMON(c) {}
+  explicit EVAL_MOS_Cgb(int c=0) :COMMON_COMPONENT(c) {}
+  bool operator==(const COMMON_COMPONENT&)const {incomplete(); return false;}
+  COMMON_COMPONENT* clone()const {untested(); return new EVAL_MOS_Cgb(*this);}
   const char* name()const	 {untested(); return "EVAL_MOS_Cgb";}
   void	tr_eval(ELEMENT*d)const;
   bool	has_tr_eval()const	 {return true;}
   bool	has_ac_eval()const	 {return false;}
 };
 /*--------------------------------------------------------------------------*/
-class EVAL_MOS_Cgd : public COMPONENT_COMMON {
+class EVAL_MOS_Cgd : public COMMON_COMPONENT {
 private:
   explicit EVAL_MOS_Cgd(const EVAL_MOS_Cgd& p) 
-    :COMPONENT_COMMON(p) {unreachable();}
+    :COMMON_COMPONENT(p) {unreachable();}
 public:
-  explicit EVAL_MOS_Cgd(int c=0) :COMPONENT_COMMON(c) {}
+  explicit EVAL_MOS_Cgd(int c=0) :COMMON_COMPONENT(c) {}
+  bool operator==(const COMMON_COMPONENT&)const {incomplete(); return false;}
+  COMMON_COMPONENT* clone()const {untested(); return new EVAL_MOS_Cgd(*this);}
   const char* name()const	 {untested(); return "EVAL_MOS_Cgd";}
   void	tr_eval(ELEMENT*d)const;
   bool	has_tr_eval()const	 {return true;}
   bool	has_ac_eval()const	 {return false;}
 };
 /*--------------------------------------------------------------------------*/
-class EVAL_MOS_Cgs : public COMPONENT_COMMON {
+class EVAL_MOS_Cgs : public COMMON_COMPONENT {
 private:
   explicit EVAL_MOS_Cgs(const EVAL_MOS_Cgs& p) 
-    :COMPONENT_COMMON(p) {unreachable();}
+    :COMMON_COMPONENT(p) {unreachable();}
 public:
-  explicit EVAL_MOS_Cgs(int c=0) :COMPONENT_COMMON(c) {}
+  explicit EVAL_MOS_Cgs(int c=0) :COMMON_COMPONENT(c) {}
+  bool operator==(const COMMON_COMPONENT&)const {incomplete(); return false;}
+  COMMON_COMPONENT* clone()const {untested(); return new EVAL_MOS_Cgs(*this);}
   const char* name()const	 {untested(); return "EVAL_MOS_Cgs";}
   void	tr_eval(ELEMENT*d)const;
   bool	has_tr_eval()const	 {return true;}
