@@ -1,4 +1,4 @@
-/*$Id: d_mosc.cc,v 18.16 2000/09/02 08:28:23 al Exp $ -*- C++ -*-
+/*$Id: d_mosc.cc,v 19.6 2001/01/16 05:58:44 al Exp $ -*- C++ -*-
  * mos model subcircuit functions
  */
 #include "d_cap.h"
@@ -25,7 +25,7 @@ void EVAL_MOS_Cgb::tr_eval(ELEMENT* d)const
   assert(brh);
   DEV_MOS* p = prechecked_cast<DEV_MOS*>(brh->owner());
   assert(p);
-  const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(p->common());
+  const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(p->common());
   assert(c);
   const SDP_MOS_BASE* b = prechecked_cast<const SDP_MOS_BASE*>(c->sdp);
   assert(b);
@@ -55,7 +55,7 @@ void EVAL_MOS_Cgd::tr_eval(ELEMENT* d)const
   assert(brh);
   DEV_MOS* p = prechecked_cast<DEV_MOS*>(brh->owner());
   assert(p);
-  const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(p->common());
+  const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(p->common());
   assert(c);
   const SDP_MOS_BASE* b = prechecked_cast<const SDP_MOS_BASE*>(c->sdp);
   assert(b);
@@ -112,7 +112,7 @@ void EVAL_MOS_Cgs::tr_eval(ELEMENT* d)const
   assert(brh);
   DEV_MOS* p = prechecked_cast<DEV_MOS*>(brh->owner());
   assert(p);
-  const MOS_COMMON* c = prechecked_cast<const MOS_COMMON*>(p->common());
+  const COMMON_MOS* c = prechecked_cast<const COMMON_MOS*>(p->common());
   assert(c);
   const SDP_MOS_BASE* b = prechecked_cast<const SDP_MOS_BASE*>(c->sdp);
   assert(b);
