@@ -1,4 +1,4 @@
-/*$Id: d_res.cc,v 17.21 2000/05/02 09:32:08 al Exp $ -*- C++ -*-
+/*$Id: d_res.cc,v 19.20 2001/05/05 07:42:40 al Exp $ -*- C++ -*-
  * functions for resistor.
  * y.x = amps,  y.f0 = volts, ev = y.f1 = ohms
  * m.x = volts, m.c0 = amps, acg = m.c1 = mhos.
@@ -43,9 +43,9 @@ bool DEV_RESISTANCE::do_tr()
     tr_eval();
     assert(_y0.f0 != LINEAR);
     if (_y0.f1 == 0.){
-      untested();
       error(bPICKY, long_label() + ": short circuit\n");
       _y0.f1 = OPT::shortckt;
+      set_converged(conv_check());
     }
     store_values();
     q_load();
