@@ -1,4 +1,4 @@
-/*$Id: d_subckt.cc,v 17.21 2000/05/02 09:32:08 al Exp $ -*- C++ -*-
+/*$Id: d_subckt.cc,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * subcircuit stuff
  * base class for other elements using internal subckts
  * netlist syntax:
@@ -32,19 +32,34 @@
 //	double	DEV_SUBCKT::tr_probe_num(CS&)const;
 /*--------------------------------------------------------------------------*/
 int DEV_SUBCKT::_count = 0;
-int SUBCKT_COMMON::_count = -1;
+int COMMON_SUBCKT::_count = -1;
 int MODEL_SUBCKT::_count = 0;
-static SUBCKT_COMMON Default_SUBCKT(CC_STATIC);
+static COMMON_SUBCKT Default_SUBCKT(CC_STATIC);
 
 struct SSNODE {
   std::string _name;
-  CARD_LIST::fat_iterator pb;
-  explicit SSNODE() :_name(), pb(&CARD_LIST::card_list) {}
-  explicit SSNODE(const std::string Name, CARD_LIST::fat_iterator c)
-    :_name(Name), pb(c) {}
+  CARD_LIST::fat_iterator _pb;
+  explicit SSNODE() :_name(), _pb(&CARD_LIST::card_list) {}
+  explicit SSNODE(const std::string& Name, CARD_LIST::fat_iterator c)
+    :_name(Name), _pb(c) {}
+  bool operator==(const SSNODE&)const{incomplete();unreachable();return false;}
+  bool operator!=(const SSNODE&)const{incomplete();unreachable();return false;}
+  bool operator<(const SSNODE&)const {incomplete();unreachable();return false;}
+  bool operator>(const SSNODE&)const {incomplete();unreachable();return false;}
+  // comparisons here because MS list requires them, even though not used here.
 };
 static std::list<SSNODE> substack;
 /*--------------------------------------------------------------------------*/
+bool COMMON_SUBCKT::operator==(const COMMON_COMPONENT& x)const
+{
+  const COMMON_SUBCKT* p = dynamic_cast<const COMMON_SUBCKT*>(&x);
+  bool rv = p && is_equal(x);
+  if (rv) {
+    untested();
+  }
+  return rv;
+}
+/*--------------------------------------------------------------------------*/
 MODEL_SUBCKT::MODEL_SUBCKT()
   :COMPONENT()
 {
@@ -109,7 +124,7 @@ void CMD::ends(CS& cmd)
 	    + "] does not match subckt [" + t._name + "]\n");
     }
   }
-  CARD_LIST::putbefore = t.pb;
+  CARD_LIST::putbefore = t._pb;
 }
 /*--------------------------------------------------------------------------*/
 DEV_SUBCKT::DEV_SUBCKT()
@@ -135,9 +150,7 @@ DEV_SUBCKT::DEV_SUBCKT(const DEV_SUBCKT& p):BASE_SUBCKT(p)
 void DEV_SUBCKT::parse(CS& cmd)
 {
   assert(has_common());
-  const SUBCKT_COMMON* cc = prechecked_cast<const SUBCKT_COMMON*>(common());
-  assert(cc);
-  SUBCKT_COMMON* c = new SUBCKT_COMMON(*cc);
+  COMMON_SUBCKT* c = prechecked_cast<COMMON_SUBCKT*>(common()->clone());
   assert(c);
   assert(!c->has_model());
 
@@ -149,7 +162,7 @@ void DEV_SUBCKT::parse(CS& cmd)
 /*--------------------------------------------------------------------------*/
 void DEV_SUBCKT::print(OMSTREAM& where, int)const
 {
-  const SUBCKT_COMMON* c = prechecked_cast<const SUBCKT_COMMON*>(common());
+  const COMMON_SUBCKT* c = prechecked_cast<const COMMON_SUBCKT*>(common());
   assert(c);
   where << short_label();
   printnodes(where, PORTSPERSUBCKT);
@@ -158,7 +171,7 @@ void DEV_SUBCKT::print(OMSTREAM& where, int)const
 /*--------------------------------------------------------------------------*/
 void DEV_SUBCKT::expand()
 {
-  const SUBCKT_COMMON* c = prechecked_cast<const SUBCKT_COMMON*>(common());
+  const COMMON_SUBCKT* c = prechecked_cast<const COMMON_SUBCKT*>(common());
   assert(c);
   expandsubckt(c->modelname());
   if (subckt().empty()){
