@@ -1,4 +1,4 @@
-/*$Id: d_subckt.h,v 17.21 2000/05/02 09:32:08 al Exp $ -*- C++ -*-
+/*$Id: d_subckt.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * data structures for subcircuits
  */
 #ifndef D_SUBCKT_H
@@ -30,13 +30,16 @@ private:
   node_t	_nodes[PORTSPERSUBCKT+1];
 };
 /*--------------------------------------------------------------------------*/
-class SUBCKT_COMMON : public COMPONENT_COMMON {
+class COMMON_SUBCKT : public COMMON_COMPONENT {
+private:
+  explicit COMMON_SUBCKT(const COMMON_SUBCKT& p):COMMON_COMPONENT(p){++_count;}
 public:
-  explicit SUBCKT_COMMON(int c=0)		:COMPONENT_COMMON(c){++_count;}
-  explicit SUBCKT_COMMON(const SUBCKT_COMMON& p):COMPONENT_COMMON(p){++_count;}
-	   ~SUBCKT_COMMON()			{--_count;}
-  const char*	name()const			{untested(); return "subckt";}
-  static int	count()				{return _count;}
+  explicit COMMON_SUBCKT(int c=0)	:COMMON_COMPONENT(c){++_count;}
+	   ~COMMON_SUBCKT()		{--_count;}
+  bool operator==(const COMMON_COMPONENT&)const;
+  COMMON_COMPONENT* clone()const	{return new COMMON_SUBCKT(*this);}
+  const char*	name()const		{untested(); return "subckt";}
+  static int	count()			{return _count;}
 private:
   static int	_count;
 };
@@ -55,6 +58,7 @@ private: // override virtual
   void		parse(CS&);
   void		print(OMSTREAM&,int)const;
   bool		is_device()const	{return false;}
+  void		map_nodes()		{}
 public:
   static int	count()			{return _count;}
 private:
