@@ -1,4 +1,4 @@
-/*$Id: d_switch.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: d_switch.cc,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * voltage (and current) controlled switch.
  * netlist syntax:
  * device:  Sxxxx n+ n- vc+ vc- mname <on>|<off> <model-card-args>
@@ -22,7 +22,18 @@
 //	void	SWITCH_BASE::do_ac();
 //	void	DEV_CSWITCH::expand();
 /*--------------------------------------------------------------------------*/
-static SWITCH_COMMON Default_SWITCH(CC_STATIC);
+static COMMON_SWITCH Default_SWITCH(CC_STATIC);
+/*--------------------------------------------------------------------------*/
+/*--------------------------------------------------------------------------*/
+bool COMMON_SWITCH::operator==(const COMMON_COMPONENT& x)const
+{
+  const COMMON_SWITCH* p = dynamic_cast<const COMMON_SWITCH*>(&x);
+  bool rv = p && is_equal(x);
+  if (rv) {
+    untested();
+  }
+  return rv;
+}
 /*--------------------------------------------------------------------------*/
 MODEL_SWITCH::MODEL_SWITCH()
   :MODEL_CARD()
@@ -104,9 +115,8 @@ SWITCH_BASE::SWITCH_BASE(const SWITCH_BASE& p)
 /*--------------------------------------------------------------------------*/
 void SWITCH_BASE::parse_sb(CS& cmd, int numnodes)
 {
-  const SWITCH_COMMON* cc = prechecked_cast<const SWITCH_COMMON*>(common());
-  assert(cc);
-  SWITCH_COMMON* c = new SWITCH_COMMON(*cc);
+  assert(has_common());
+  COMMON_SWITCH* c = prechecked_cast<COMMON_SWITCH*>(common()->clone());
   assert(c);
   assert(!c->has_model());
 
@@ -133,7 +143,7 @@ void SWITCH_BASE::parse_sb(CS& cmd, int numnodes)
 /*--------------------------------------------------------------------------*/
 void SWITCH_BASE::print(OMSTREAM& where, int)const
 {
-  const SWITCH_COMMON* c = prechecked_cast<const SWITCH_COMMON*>(common());
+  const COMMON_SWITCH* c = prechecked_cast<const COMMON_SWITCH*>(common());
   assert(c);
   where << short_label();
   printnodes(where, numnodes());
@@ -165,7 +175,7 @@ void SWITCH_BASE::expand_sb()
 /*--------------------------------------------------------------------------*/
 void SWITCH_BASE::precalc()
 {
-  const SWITCH_COMMON* c = prechecked_cast<const SWITCH_COMMON*>(common());
+  const COMMON_SWITCH* c = prechecked_cast<const COMMON_SWITCH*>(common());
   assert(c);
   const MODEL_SWITCH* m = prechecked_cast<const MODEL_SWITCH*>(c->model());
   assert(m);
@@ -184,7 +194,7 @@ void SWITCH_BASE::precalc()
 /*--------------------------------------------------------------------------*/
 void SWITCH_BASE::dc_begin()
 {
-  const SWITCH_COMMON* c = prechecked_cast<const SWITCH_COMMON*>(common());
+  const COMMON_SWITCH* c = prechecked_cast<const COMMON_SWITCH*>(common());
   assert(c);
   const MODEL_SWITCH* m = prechecked_cast<const MODEL_SWITCH*>(c->model());
   assert(m);
@@ -201,7 +211,7 @@ void SWITCH_BASE::dc_begin()
 /*--------------------------------------------------------------------------*/
 bool SWITCH_BASE::do_tr()
 {
-  const SWITCH_COMMON* c = prechecked_cast<const SWITCH_COMMON*>(common());
+  const COMMON_SWITCH* c = prechecked_cast<const COMMON_SWITCH*>(common());
   assert(c);
   const MODEL_SWITCH* m = prechecked_cast<const MODEL_SWITCH*>(c->model());
   assert(m);
