@@ -1,4 +1,4 @@
-/*$Id: d_switch.h,v 17.21 2000/05/02 09:32:08 al Exp $ -*- C++ -*-
+/*$Id: d_switch.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * data structures for voltage (and current) controlled switch
  */
 #ifndef D_SWITCH_H
@@ -26,11 +26,14 @@ private:
   control_t type;	/* current or voltage controlled */
 };
 /*--------------------------------------------------------------------------*/
-class SWITCH_COMMON : public COMPONENT_COMMON {
+class COMMON_SWITCH : public COMMON_COMPONENT {
+private:
+  explicit COMMON_SWITCH(const COMMON_SWITCH& p):COMMON_COMPONENT(p) {}
 public:
-  explicit SWITCH_COMMON(int c=0)		:COMPONENT_COMMON(c) {}
-  explicit SWITCH_COMMON(const SWITCH_COMMON& p):COMPONENT_COMMON(p) {}
-  const char* name()const			{untested(); return "switch";}
+  explicit COMMON_SWITCH(int c=0)	:COMMON_COMPONENT(c) {}
+  bool operator==(const COMMON_COMPONENT&)const;
+  COMMON_COMPONENT* clone()const	{return new COMMON_SWITCH(*this);}
+  const char* name()const		{untested(); return "switch";}
 };
 /*--------------------------------------------------------------------------*/
 class SWITCH_BASE : public ELEMENT {
@@ -47,6 +50,7 @@ private: // override virtual
   void	   parse(CS&)		= 0;
   void     print(OMSTREAM&,int)const;
   void     expand()		= 0;		
+  //void   map_nodes();		//ELEMENT
   void     precalc();
 
   void	   dc_begin();
