@@ -1,55 +1,17 @@
-/*$Id: d_trln.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: d_trln.cc,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * Transmission line. (ideal lossless.)
  */
 #include "ap.h"
-#include "m_interp.h"
-#include "l_denoise.h"
 #include "d_trln.h"
 /*--------------------------------------------------------------------------*/
 const double LINLENTOL = .000001;
 const double default_nl = 0.25;
 const double default_z0 = 50;
 const char* default_z0_string = "50";
-static TRANSLINE_COMMON Default_TRANSLINE(CC_STATIC);
+static COMMON_TRANSLINE Default_TRANSLINE(CC_STATIC);
 /*--------------------------------------------------------------------------*/
-inline void WAVE::push(double t, double v)
-{
-  _w.push_back(std::pair<double,double>(t+_delay, v));
-}
-/*--------------------------------------------------------------------------*/
-inline void WAVE::initialize()
-{
-  _w.clear();
-  push(0-_delay, 0.);
-  push(0., 0.);
-}
-/*--------------------------------------------------------------------------*/
-WAVE::WAVE(double d)
-  :_w(),
-   _delay(d)
-{
-  initialize();
-}
-/*--------------------------------------------------------------------------*/
-inline void WAVE::set_delay(double d) 
-{
-  _delay = d; 
-  initialize();
-}
-/*--------------------------------------------------------------------------*/
-inline double WAVE::v_out(double t)const
-{
-  FPOLY1 rv=interpolate(_w.begin(), _w.end(), t, 0., 0.);
-  return rv.f0;
-}
-/*--------------------------------------------------------------------------*/
-inline double WAVE::v_reflect(double t, double v_total)const
-{
-  return dn_diff(v_total*2, v_out(t));
-}
-/*--------------------------------------------------------------------------*/
-TRANSLINE_COMMON::TRANSLINE_COMMON(int c)
-  :COMPONENT_COMMON(c),
+COMMON_TRANSLINE::COMMON_TRANSLINE(int c)
+  :COMMON_COMPONENT(c),
    z0(NOT_INPUT),
    td(NOT_INPUT),
    f(NOT_INPUT),
@@ -61,8 +23,8 @@ TRANSLINE_COMMON::TRANSLINE_COMMON(int c)
   }
 }
 /*--------------------------------------------------------------------------*/
-TRANSLINE_COMMON::TRANSLINE_COMMON(const TRANSLINE_COMMON& p)
-  :COMPONENT_COMMON(p),
+COMMON_TRANSLINE::COMMON_TRANSLINE(const COMMON_TRANSLINE& p)
+  :COMMON_COMPONENT(p),
    z0(p.z0),
    td(p.td),
    f(p.f),
@@ -74,6 +36,25 @@ TRANSLINE_COMMON::TRANSLINE_COMMON(const TRANSLINE_COMMON& p)
   }
 }
 /*--------------------------------------------------------------------------*/
+bool COMMON_TRANSLINE::operator==(const COMMON_COMPONENT& x)const
+{
+  const COMMON_TRANSLINE* p = dynamic_cast<const COMMON_TRANSLINE*>(&x);
+  bool rv = p
+    && z0 == p->z0
+    && td == p->td
+    && f == p->f
+    && nl == p->nl
+    && icset == p->icset
+    && is_equal(x);
+  if (rv) {
+    untested();
+    {for (int i=0; i<NUM_INIT_COND; ++i) {
+      rv &= ic[i] == p->ic[i];
+    }}
+  }
+  return rv;
+}
+/*--------------------------------------------------------------------------*/
 DEV_TRANSLINE::DEV_TRANSLINE()
   :ELEMENT(),
    _forward(), _reflect(),
@@ -85,9 +66,8 @@ DEV_TRANSLINE::DEV_TRANSLINE()
 /*--------------------------------------------------------------------------*/
 void DEV_TRANSLINE::parse(CS& cmd)
 {
-  const TRANSLINE_COMMON* cc = prechecked_cast<const TRANSLINE_COMMON*>(common());
-  assert(cc);
-  TRANSLINE_COMMON* c = new TRANSLINE_COMMON(*cc);
+  assert(has_common());
+  COMMON_TRANSLINE* c = prechecked_cast<COMMON_TRANSLINE*>(common()->clone());
   assert(c);
 
   parse_Label(cmd);
@@ -161,7 +141,7 @@ void DEV_TRANSLINE::parse(CS& cmd)
 /*--------------------------------------------------------------------------*/
 void DEV_TRANSLINE::print(OMSTREAM& where, int)const
 {
-  const TRANSLINE_COMMON*c=prechecked_cast<const TRANSLINE_COMMON*>(common());
+  const COMMON_TRANSLINE*c=prechecked_cast<const COMMON_TRANSLINE*>(common());
   assert(c);
   where << short_label();
   printnodes(where,numnodes());
@@ -183,7 +163,7 @@ void DEV_TRANSLINE::print(OMSTREAM& where, int)const
 /*--------------------------------------------------------------------------*/
 void DEV_TRANSLINE::precalc()
 {
-  const TRANSLINE_COMMON* c=prechecked_cast<const TRANSLINE_COMMON*>(common());
+  const COMMON_TRANSLINE* c=prechecked_cast<const COMMON_TRANSLINE*>(common());
   assert(c);
   _forward.set_delay(c->td);
   _reflect.set_delay(c->td);
@@ -201,7 +181,7 @@ void DEV_TRANSLINE::tr_begin()
  */
 void DEV_TRANSLINE::tr_advance()
 {
-  const TRANSLINE_COMMON* c=prechecked_cast<const TRANSLINE_COMMON*>(common());
+  const COMMON_TRANSLINE* c=prechecked_cast<const COMMON_TRANSLINE*>(common());
   assert(c);
   _if0 = _forward.v_out(SIM::time0)/c->z0;
   _ir0 = _reflect.v_out(SIM::time0)/c->z0;
@@ -230,8 +210,8 @@ void DEV_TRANSLINE::tr_load()
   double lvf = NOT_VALID; // load value, forward
   double lvr = NOT_VALID; // load value, reflected
   {if (!SIM::inc_mode){
-    const TRANSLINE_COMMON* 
-      c = prechecked_cast<const TRANSLINE_COMMON*>(common());
+    const COMMON_TRANSLINE* 
+      c = prechecked_cast<const COMMON_TRANSLINE*>(common());
     assert(c);
     aa.load_symmetric(_n[OUT1].m, _n[OUT2].m, 1/c->z0);
     aa.load_symmetric(_n[IN1].m,  _n[IN2].m,  1/c->z0);
@@ -272,7 +252,7 @@ void DEV_TRANSLINE::tr_load()
 double DEV_TRANSLINE::tr_review()
 {
   q_accept();
-  const TRANSLINE_COMMON* c=prechecked_cast<const TRANSLINE_COMMON*>(common());
+  const COMMON_TRANSLINE* c=prechecked_cast<const COMMON_TRANSLINE*>(common());
   assert(c);
   return SIM::time0 + c->td; // ok to miss the spikes, for now
 }
@@ -292,7 +272,7 @@ void DEV_TRANSLINE::tr_unload()
 /*--------------------------------------------------------------------------*/
 void DEV_TRANSLINE::do_ac()
 {
-  const TRANSLINE_COMMON*c=prechecked_cast<const TRANSLINE_COMMON*>(common());
+  const COMMON_TRANSLINE*c=prechecked_cast<const COMMON_TRANSLINE*>(common());
   assert(c);
   double lenth = SIM::freq * c->td * 4;	/* length in quarter waves */
   double dif = lenth - floor(lenth+.5);	/* avoid divide by zero if close to */
