@@ -1,30 +1,20 @@
-/*$Id: d_trln.h,v 17.21 2000/05/02 09:32:08 al Exp $ -*- C++ -*-
+/*$Id: d_trln.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * transmission lines
  */
 #ifndef D_TRNLIN_H
 #define D_TRNLIN_H
+#include "m_wave.h"
 #include "e_elemnt.h"
 /*--------------------------------------------------------------------------*/
 enum {NUM_INIT_COND = 4};
 /*--------------------------------------------------------------------------*/
-class WAVE {
+class COMMON_TRANSLINE : public COMMON_COMPONENT {
 private:
-  std::deque<std::pair<double,double> > _w;
-  double _delay;
-  explicit WAVE(const WAVE&);
+  explicit COMMON_TRANSLINE(const COMMON_TRANSLINE& p);
 public:
-  explicit WAVE(double d=0);
-  void	   set_delay(double d);
-  void	   initialize();
-  void	   push(double t, double v);
-  double   v_out(double t)const;
-  double   v_reflect(double t, double v_total)const;
-};
-/*--------------------------------------------------------------------------*/
-class TRANSLINE_COMMON : public COMPONENT_COMMON {
-public:
-  explicit TRANSLINE_COMMON(int c=0);
-  explicit TRANSLINE_COMMON(const TRANSLINE_COMMON& p);
+  explicit COMMON_TRANSLINE(int c=0);
+  bool operator==(const COMMON_COMPONENT&)const;
+  COMMON_COMPONENT* clone()const {return new COMMON_TRANSLINE(*this);}
   const char* name()const	{untested(); return "transline";}
   double   z0;			/* characteristic impedance */
   double   td;			/* delay time */
@@ -58,6 +48,7 @@ private: // override virtual
   void		parse(CS&);
   void		print(OMSTREAM&,int)const;
   //void	expand();		//CARD/nothing
+  //void	map_nodes();		//ELEMENT
   void		precalc();
 
   void		dc_begin()		{untested();}
