@@ -1,17 +1,17 @@
-/*$Id: e_card.h,v 18.11 2000/08/30 05:19:43 al Exp $ -*- C++ -*-
+/*$Id: e_card.h,v 19.19 2001/04/29 03:14:10 al Exp $ -*- C++ -*-
  * base class for anything in a netlist or circuit file
  */
-#include "e_node.h"
-#include "e_cardlist.h"
 #ifndef E_CARD_H
 #define E_CARD_H
+#include "e_node.h"
+#include "e_cardlist.h"
 /*--------------------------------------------------------------------------*/
 // this file
 class CARD;
 /*--------------------------------------------------------------------------*/
 // external
 class CS;
-class COMPONENT_COMMON;
+class COMMON_COMPONENT;
 /*--------------------------------------------------------------------------*/
 class CARD : public CKT_BASE {
 private:
@@ -34,6 +34,7 @@ public:					// virtuals. -- the important stuff
   virtual void	 parse(CS&)		= 0;
   virtual void	 print(OMSTREAM&,int)const = 0;
   virtual void	 expand()		{}
+  virtual void	 map_nodes()		{}
   virtual void	 precalc()		{}
   virtual void	 dc_begin()		{}
   virtual void	 tr_begin()		{}
@@ -88,7 +89,7 @@ public:					// query functions.
 public:					// modifiers.
   virtual void	set_slave()		{untested(); subckt().set_slave();}
   virtual void  set_value(double v)	{_value = v;}
-  virtual void  set_value(double v, const COMPONENT_COMMON*)
+  virtual void  set_value(double v, COMMON_COMPONENT*)
 					{untested(); set_value(v);}
   double* set_value()		{return &_value;}
   void	  parse_label(CS&);
