@@ -1,4 +1,4 @@
-/*$Id: e_cardlist.cc,v 16.15 1999/12/20 09:18:34 al Exp $ -*- C++ -*-
+/*$Id: e_cardlist.cc,v 19.12 2001/02/24 03:40:45 al Exp $ -*- C++ -*-
  * Base class for "cards" in the circuit description file
  * This file contains functions that process a list of cards
  *
@@ -27,6 +27,7 @@ CARD_LIST& CARD_LIST::erase(iterator ci)
 /*--------------------------------------------------------------------------*/
 CARD_LIST& CARD_LIST::erase(CARD* c)
 {
+  delete c;
   _cl.remove(c);
   return *this;
 }
@@ -36,7 +37,7 @@ CARD_LIST& CARD_LIST::erase(CARD* c)
  */
 CARD_LIST& CARD_LIST::set_slave()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).set_slave();
   }
   return *this;
@@ -48,19 +49,29 @@ CARD_LIST& CARD_LIST::set_slave()
  */
 CARD_LIST& CARD_LIST::expand()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).expand();
   }
   return *this;
 }
 /*--------------------------------------------------------------------------*/
+/* map_nodes: create mapping between user node names and internal numbers
+ */
+CARD_LIST& CARD_LIST::map_nodes()
+{
+  for (iterator ci=begin(); ci!=end(); ++ci) {
+    (**ci).map_nodes();
+  }
+  return *this;
+}
+/*--------------------------------------------------------------------------*/
 /* precalc: precalculate anything that can be done up front for all modes
  * Also initializes some internal data (the polys, etc),
  * finds out what is constant, etc.
  */
 CARD_LIST& CARD_LIST::precalc()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).precalc();
   }
   return *this;
@@ -70,7 +81,7 @@ CARD_LIST& CARD_LIST::precalc()
  */
 CARD_LIST& CARD_LIST::dc_begin()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).dc_begin();
   }
   return *this;
@@ -80,7 +91,7 @@ CARD_LIST& CARD_LIST::dc_begin()
  */
 CARD_LIST& CARD_LIST::tr_begin()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).tr_begin();
   }
   return *this;
@@ -90,7 +101,7 @@ CARD_LIST& CARD_LIST::tr_begin()
  */
 CARD_LIST& CARD_LIST::tr_restore()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).tr_restore();
   }
   return *this;
@@ -100,7 +111,7 @@ CARD_LIST& CARD_LIST::tr_restore()
  */
 CARD_LIST& CARD_LIST::dc_advance()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).dc_advance();
   }
   return *this;
@@ -110,7 +121,7 @@ CARD_LIST& CARD_LIST::dc_advance()
  */
 CARD_LIST& CARD_LIST::tr_advance()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).tr_advance();
   }
   return *this;
@@ -121,7 +132,7 @@ CARD_LIST& CARD_LIST::tr_advance()
 bool CARD_LIST::tr_needs_eval()
 {
   bool needs = false;
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     needs |= (**ci).tr_needs_eval();
   }
   return needs;
@@ -131,7 +142,7 @@ bool CARD_LIST::tr_needs_eval()
  */
 CARD_LIST& CARD_LIST::tr_queue_eval()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).tr_queue_eval();
   }
   return *this;
@@ -146,14 +157,14 @@ CARD_LIST& CARD_LIST::tr_queue_eval()
 bool CARD_LIST::do_tr()
 {
   bool isconverged = true;
-  {if (OPT::bypass){
-    for (iterator ci=begin(); ci!=end(); ++ci){
-      if ((**ci).tr_needs_eval()){
+  {if (OPT::bypass) {
+    for (iterator ci=begin(); ci!=end(); ++ci) {
+      if ((**ci).tr_needs_eval()) {
 	isconverged &= (**ci).do_tr();
       }
     }
   }else{
-    for (iterator ci=begin(); ci!=end(); ++ci){
+    for (iterator ci=begin(); ci!=end(); ++ci) {
       isconverged &= (**ci).do_tr();
     }
   }}
@@ -165,12 +176,10 @@ bool CARD_LIST::do_tr()
  */
 CARD_LIST& CARD_LIST::tr_load()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     CARD* brh = *ci;
-    if (!brh->constant() || !SIM::inc_mode){
+    if (!brh->constant() || !SIM::inc_mode) {
       brh->tr_load();
-    }else{
-      untested();
     }
   }
   return *this;
@@ -179,9 +188,9 @@ CARD_LIST& CARD_LIST::tr_load()
 double CARD_LIST::tr_review()
 {
   double worsttime = BIGBIG;
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     double thistime = (**ci).tr_review();
-    if (thistime < worsttime){
+    if (thistime < worsttime) {
       worsttime = thistime;
     }
   }
@@ -192,7 +201,7 @@ double CARD_LIST::tr_review()
  */
 CARD_LIST& CARD_LIST::tr_accept()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).tr_accept();
   }
   return *this;
@@ -203,7 +212,7 @@ CARD_LIST& CARD_LIST::tr_accept()
  */
 CARD_LIST& CARD_LIST::tr_unload()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).tr_unload();
   }
   return *this;
@@ -213,7 +222,7 @@ CARD_LIST& CARD_LIST::tr_unload()
  */
 CARD_LIST& CARD_LIST::ac_begin()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).ac_begin();
   }
   return *this;
@@ -221,7 +230,7 @@ CARD_LIST& CARD_LIST::ac_begin()
 /*--------------------------------------------------------------------------*/
 CARD_LIST& CARD_LIST::do_ac()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     if (!(**ci).evaluated())
       (**ci).do_ac();
   }
@@ -233,7 +242,7 @@ CARD_LIST& CARD_LIST::do_ac()
  */
 CARD_LIST& CARD_LIST::ac_load()
 {
-  for (iterator ci=begin(); ci!=end(); ++ci){
+  for (iterator ci=begin(); ci!=end(); ++ci) {
     (**ci).ac_load();
   }
   return *this;
@@ -245,7 +254,7 @@ CARD_LIST& CARD_LIST::ac_load()
  */
 CARD_LIST& CARD_LIST::destroy()
 {
-  while (!_cl.empty()){
+  while (!_cl.empty()) {
     delete _cl.back();
     _cl.pop_back();
   }
@@ -262,7 +271,7 @@ CARD* CARD::find_in_scope(const std::string& name)
 {
   CARD_LIST& cl = (owner()) ? owner()->subckt() : CARD_LIST::card_list;
   CARD_LIST::iterator ci = cl.find(name);
-  if (ci == cl.end()){
+  if (ci == cl.end()) {
     error(bERROR, "can't find: " + name + '\n');
     return NULL;
   }else{
