@@ -1,4 +1,4 @@
-/*$Id: e_compon.cc,v 18.8 2000/07/26 09:26:27 al Exp $ -*- C++ -*-
+/*$Id: e_compon.cc,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * Base class for elements of a circuit
  */
 #include "l_stlextra.h"
@@ -9,49 +9,63 @@
 /*--------------------------------------------------------------------------*/
 static	int	name2number(CS&);
 /*--------------------------------------------------------------------------*/
-COMPONENT_COMMON::~COMPONENT_COMMON()
+COMMON_COMPONENT::~COMMON_COMPONENT()
 {
   trace1("common", _attachcount);
-  assert(_attachcount==0||_attachcount==CC_STATIC);
+  assert(_attach_count == 0 || _attach_count == CC_STATIC);
 }
 /*--------------------------------------------------------------------------*/
-const MODEL_CARD* COMPONENT_COMMON::attach_model()const
+const MODEL_CARD* COMMON_COMPONENT::attach_model()const
 {
-  std::list<CARD*>::const_iterator mi =
-    find_ptr(root_model_list.begin(), root_model_list.end(), _modelname);
-  {if (mi == root_model_list.end()){
-    untested();
-    error(bERROR, "can't find model: " + modelname() + '\n');
-    _model = 0;
+  {if (modelname() != "") {
+    std::list<CARD*>::const_iterator mi =
+      find_ptr(root_model_list.begin(), root_model_list.end(), modelname());
+    {if (mi == root_model_list.end()) {
+      error(bERROR, "can't find model: " + modelname() + '\n');
+      _model = 0;
+    }else{
+      _model = dynamic_cast<const MODEL_CARD*>(*mi);
+      if (!_model) {
+	untested();
+	error(bERROR, modelname() + " is not a .model\n");
+      }
+    }}
   }else{
-    _model = dynamic_cast<const MODEL_CARD*>(*mi);
-    if (!_model){
-      untested();
-      error(bERROR, modelname() + " is not a .model\n");
-    }
+    untested();
+    assert(!_model);
   }}
   return _model;
 }
 /*--------------------------------------------------------------------------*/
-COMPONENT_COMMON& COMPONENT_COMMON::parse_modelname(CS& cmd)
+void COMMON_COMPONENT::parse_modelname(CS& cmd)
 {
-  return set_modelname(cmd.ctos(TOKENTERM));
+  set_modelname(cmd.ctos(TOKENTERM));
 }
 /*--------------------------------------------------------------------------*/
-void COMPONENT_COMMON::tr_eval(ELEMENT*x)const
+void COMMON_COMPONENT::tr_eval(ELEMENT*x)const
 {
   untested();
   assert(_model);
   _model->tr_eval(x);
 }
 /*--------------------------------------------------------------------------*/
-void COMPONENT_COMMON::ac_eval(ELEMENT*x)const
+void COMMON_COMPONENT::ac_eval(ELEMENT*x)const
 {
   untested();
   assert(_model);
   _model->ac_eval(x);
 }
 /*--------------------------------------------------------------------------*/
+bool COMMON_COMPONENT::is_equal(const COMMON_COMPONENT& x)const
+{
+  bool rv = _tnom == x._tnom
+    && _modelname == x._modelname;
+  if (rv) {
+    assert(!_model || !x._model || _model == x._model);
+  }
+  return rv;
+}
+/*--------------------------------------------------------------------------*/
 COMPONENT::COMPONENT()
   :CARD(),
    _common(0),
@@ -78,22 +92,22 @@ COMPONENT::COMPONENT(const COMPONENT& p)
 int COMPONENT::parse_nodes(CS& cmd, int numnodes, int minfill, int start)
 {
   int count = 0;
-  if (start < numnodes){
+  if (start < numnodes) {
     int paren = cmd.skiplparen();
-    for (int ii = start;  ii < numnodes;  ++ii){
+    for (int ii = start;  ii < numnodes;  ++ii) {
       _n[ii].t = _n[ii].e = name2number(cmd);
-      if (_n[ii].e != INVALIDNODE){
+      if (_n[ii].e != INVALIDNODE) {
 	count = ii+1;
       }else{
-	if (ii <= minfill){
-	  cmd.warn(bDANGER, "need mode nodes");
+	if (ii <= minfill) {
+	  cmd.warn(bDANGER, "need more nodes");
 	  _n[ii].t = _n[ii].e = 0;
 	}
       }
     }
     _n[numnodes].t = _n[numnodes].e = INVALIDNODE;
     paren -= cmd.skiprparen();
-    if (paren != 0){
+    if (paren != 0) {
       untested();
       cmd.warn(bWARNING, "need )");
     }
@@ -105,15 +119,44 @@ int COMPONENT::parse_nodes(CS& cmd, int numnodes, int minfill, int start)
  */
 void COMPONENT::printnodes(OMSTREAM& where, int numnodes, int start)const
 {
-  for (int ii = start;  ii < numnodes  &&  _n[ii].e != INVALIDNODE;  ++ii){
+  for (int ii = start;  ii < numnodes  &&  _n[ii].e != INVALIDNODE;  ++ii) {
     where << "  " << _n[ii];
   }
 }
 /*--------------------------------------------------------------------------*/
+void COMPONENT::deflate_common()
+{
+  if (has_common()) {
+    COMMON_COMPONENT* dc = mutable_common()->deflate();
+    if (dc != common()) {
+      untested();
+      attach_common(dc);
+    }
+  }
+}
+/*--------------------------------------------------------------------------*/
+void COMPONENT::expand()
+{
+  if (has_common()) {
+    mutable_common()->expand();
+  }
+  deflate_common();
+}
+/*--------------------------------------------------------------------------*/
+void COMPONENT::map_nodes()
+{
+  assert(is_device());
+  int ii;
+  for (ii = 0;  _n[ii].t != INVALIDNODE;  ++ii) {
+    _n[ii].map();
+  }
+  assert(_n[ii].m == INVALIDNODE);
+}
+/*--------------------------------------------------------------------------*/
 /* set: set values, used in model building, 2 node version
  */
 void COMPONENT::set(const std::string& Label, CARD *Owner,
-		    const COMPONENT_COMMON *Common, double Value,
+		    COMMON_COMPONENT *Common, double Value,
 		    const node_t& N0, const node_t& N1,
 		    const node_t& N2, const node_t& N3)
 {
@@ -127,35 +170,50 @@ void COMPONENT::set(const std::string& Label, CARD *Owner,
   _n[3] = N3;
 }
 /*--------------------------------------------------------------------------*/
-void attach_common(const COMPONENT_COMMON *c, const COMPONENT_COMMON** to)
+void COMPONENT::set_value(double v, COMMON_COMPONENT* c)
+{
+  if (c != _common) {
+    detach_common();
+    attach_common(c);
+  }
+  set_value(v);
+}
+/*--------------------------------------------------------------------------*/
+/*--------------------------------------------------------------------------*/
+void attach_common(COMMON_COMPONENT *c, COMMON_COMPONENT** to)
 {
   assert(to);
-  {if (!c){
-    // there is no new common.  probably a simple element
+  {if (c == *to) {
+    // The new and old are the same.  Do nothing.
+  }else if (!c) {
+    // There is no new common.  probably a simple element
+    untested();
     detach_common(to);
-  }else if (!*to){
-    // no old one, but have a new one
-    *to = c->a_ttach();
-  }else{ /* if (1 || *c != *common){*/
-    // they are different
+  }else if (!*to) {
+    // No old one, but have a new one.
+    *to = c->attach();
+  }else if (*c != **to) {
+    // They are different, usually by edit.
     detach_common(to);
-    *to = c->a_ttach();
-#if 0
+    *to = c->attach();
+  }else if (c->_attach_count == 0) {
+    // The one already attached matches the new one. 
+    // Use the old one.
+    // The new one is not used anywhere, so throw it away.
+    delete c;
   }else{
     untested();
     // The one already attached matches the new one. 
-    // use the old one and throw away the new one.
-    // doesn't work.  always assume different as workaround
-    delete c;
-#endif
+    // Use the old one.
+    // The new one is also used somewhere else, so keep it.
   }}
 }
 /*--------------------------------------------------------------------------*/
-void detach_common(const COMPONENT_COMMON** from)
+void detach_common(COMMON_COMPONENT** from)
 {
   assert(from);
-  if (*from){
-    if ((**from).d_etach() == 0){
+  if (*from) {
+    if ((**from).detach() == 0) {
       trace1("delete", (**from)._attachcount);
       delete *from;
     }else{
