@@ -1,4 +1,4 @@
-/*$Id: e_compon.h,v 18.8 2000/07/26 09:26:27 al Exp $ -*- C++ -*-
+/*$Id: e_compon.h,v 19.23 2001/05/11 21:30:50 al Exp $ -*- C++ -*-
  * branch structure type definitions
  * device types (enumeration type?)
  */
@@ -8,7 +8,7 @@
 #include "e_card.h"
 /*--------------------------------------------------------------------------*/
 // this file
-class COMPONENT_COMMON;
+class COMMON_COMPONENT;
 class COMPONENT;
 /*--------------------------------------------------------------------------*/
 // external
@@ -25,58 +25,60 @@ enum {CC_STATIC=27342}; // mid-sized arbitrary positive int
 // pass this as an argument to a common constructor to mark it as static,
 // so it won't be deleted
 /*--------------------------------------------------------------------------*/
-class COMPONENT_COMMON {
-friend void attach_common(const COMPONENT_COMMON*c,const COMPONENT_COMMON**to);
-friend void detach_common(const COMPONENT_COMMON** from);
+class COMMON_COMPONENT {
+friend void attach_common(COMMON_COMPONENT* c, COMMON_COMPONENT** to);
+friend void detach_common(COMMON_COMPONENT** from);
 private:
-  COMPONENT_COMMON& operator=(const COMPONENT_COMMON&)
+  COMMON_COMPONENT& operator=(const COMMON_COMPONENT&)
 					{unreachable(); return *this;}
 protected:
-  explicit COMPONENT_COMMON(const COMPONENT_COMMON& p, int c=0)
-    :_tnom(p._tnom),_modelname(p._modelname),_model(p._model),_attachcount(c)
+  explicit COMMON_COMPONENT(const COMMON_COMPONENT& p, int c=0)
+    :_tnom(p._tnom),_modelname(p._modelname),_model(p._model),_attach_count(c)
     {}
-  explicit COMPONENT_COMMON(int c=0)
-    :_tnom(NOT_INPUT),_modelname(), _model(0), _attachcount(c) {}
+  explicit COMMON_COMPONENT(int c=0)
+    :_tnom(NOT_INPUT),_modelname(), _model(0), _attach_count(c) {}
 public:
-  virtual ~COMPONENT_COMMON();
-  //	{assert(_attachcount==0||_attachcount==CC_STATIC);}
+  virtual ~COMMON_COMPONENT();
 
+  virtual bool operator==(const COMMON_COMPONENT&)const = 0;
   const MODEL_CARD* attach_model()const;
-  COMPONENT_COMMON& attach(const MODEL_CARD* m) {_model = m; return *this;}
-  COMPONENT_COMMON& set_modelname(const std::string& n)
-					{_modelname = n; return *this;}
-  COMPONENT_COMMON& parse_modelname(CS&);
+  COMMON_COMPONENT& attach(const MODEL_CARD* m) {_model = m; return *this;}
+  void set_modelname(const std::string& n) {_modelname = n;}
+  void parse_modelname(CS&);
 
+  virtual COMMON_COMPONENT* clone()const = 0;
   virtual void	parse(CS&)		{unreachable();}
   virtual void	print(OMSTREAM&)const	{unreachable();}
+  virtual void	expand()		{assert(_modelname == "");}
 
   virtual void	tr_eval(ELEMENT*x)const;
   virtual void	ac_eval(ELEMENT*x)const;
   virtual bool	has_tr_eval()const	{untested(); return false;}
   virtual bool	has_ac_eval()const	{untested(); return false;}
-  virtual const COMPONENT_COMMON* deflate()const {return this;}
+  virtual COMMON_COMPONENT* deflate()	{return this;}
 
   virtual const char* name()const	= 0;
   const std::string&  modelname()const	{return _modelname;}
   const MODEL_CARD*   model()const	{assert(_model); return _model;}
 	  bool	      has_model()const	{return _model;}
+
+  bool is_equal(const COMMON_COMPONENT&)const;
 private:
-  const COMPONENT_COMMON* a_ttach()const	{++_attachcount; return this;}
-  int d_etach()const		{assert(_attachcount>0);return --_attachcount;}
+  COMMON_COMPONENT* attach() {++_attach_count; return this;}
+  int detach()		     {assert(_attach_count>0);return --_attach_count;}
 protected:
   double	_tnom;
 private:
   std::string	_modelname;
   mutable const MODEL_CARD* _model;
-public:
-  mutable int	_attachcount;
+  int		_attach_count;
 };
 /*--------------------------------------------------------------------------*/
-/* note on _attachcount ...
- * The int argument is the initial _attachcount (default = 0)
+/* note on _attach_count ...
+ * The int argument is the initial _attach_count (default = 0)
  * Set it to CC_STATIC for static default versions that will never be deleted.
  * Set it to 0 (default) for auto versions, so they can be deleted.
- * A common will not be deleted on a detach if its _attachcount != 0
+ * A common will not be deleted on a detach if its _attach_count != 0
  * A failed assertion from the common destructor probably means
  * the common is being deleted before a device it is attached to is,
  * without being first detached.
@@ -95,15 +97,19 @@ protected:
 public:
   virtual const char* dev_type()const = 0;
   virtual int	      numnodes()const = 0;
-protected:
+protected: // override virtual
+  void  expand();
+  bool	is_device()const		{return true;}
+  void  map_nodes();
+protected: // not virtual
   int	parse_nodes(CS&,int,int,int=0);
   void	printnodes(OMSTREAM&,int,int=0)const;
-  bool	is_device()const		{return true;}
 
   const MODEL_CARD* attach_model()const	
 		{return (has_common() ? _common->attach_model() : 0);}
-  void	attach_common(const COMPONENT_COMMON*c) {::attach_common(c,&_common);}
+  void	attach_common(COMMON_COMPONENT*c) {::attach_common(c,&_common);}
   void	detach_common()			{::detach_common(&_common);}
+  void	deflate_common();
 
   bool	converged()const		{return _converged;}
   void	set_converged(bool s=true)	{_converged = s;}
@@ -121,21 +127,22 @@ protected:
   // modifiers
 public:
   void	set(const std::string& Label, CARD* Parent,
-	    const COMPONENT_COMMON* Common, double Value,
+	    COMMON_COMPONENT* Common, double Value,
 	    const node_t& N0, const node_t& N1,
 	    const node_t& N2 = node_t(), const node_t& N3 = node_t());
-  void	set_slave()	{_queued_for_eval = INT_MAX; subckt().set_slave();}
-  void	set_value(double v)			      {CARD::set_value(v);}
-  void	set_value(double v, const COMPONENT_COMMON* c){_common=c;set_value(v);}
+  void	set_slave()	    {_queued_for_eval = INT_MAX; subckt().set_slave();}
+  void	set_value(double v) {CARD::set_value(v);}
+  void	set_value(double v, COMMON_COMPONENT* c);
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // querys
   bool	is_slave()const	  {untested(); return (_queued_for_eval==INT_MAX);}
   bool	has_common()const {return _common;}
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // data access
-  const COMPONENT_COMMON* common()const	{return _common;}
+  COMMON_COMPONENT*	  mutable_common()	{return _common;}
+  const COMMON_COMPONENT* common()const		{return _common;}
 private:
-  const COMPONENT_COMMON* _common;
+  COMMON_COMPONENT* _common;
 private:
   bool _converged;	// convergence status
   int  _queued_for_eval;
