@@ -1,4 +1,4 @@
-/*$Id: e_elemnt.cc,v 18.8 2000/07/26 09:26:27 al Exp $ -*- C++ -*-
+/*$Id: e_elemnt.cc,v 19.20 2001/05/05 07:42:40 al Exp $ -*- C++ -*-
  * Base class for elements of a circuit
  */
 #include "u_xprobe.h"
@@ -53,27 +53,38 @@ void ELEMENT::parse_more_nodes(CS& cmd, int gotnodes)
 {
   int inports = is_2port();
   parse_nodes(cmd, 2*inports+2, 2*inports+2, gotnodes);
+  //		   max		min	     start
 }
 /*--------------------------------------------------------------------------*/
 void ELEMENT::parse(CS& cmd)
 {
   parse_Label(cmd);
   int gotnodes = parse_nodes(cmd,numnodes(),0);
-  COMPONENT_COMMON* c = 0;
-  if (gotnodes < numnodes()) {		// function name between nodes
+  //				 max	    min
+  COMMON_COMPONENT* c = 0;
+
+  // HSPICE compatibility kluge.
+  // The device type or function type could be stuck between the nodes.
+  if (gotnodes < numnodes()) {
     skip_dev_type(cmd); // (redundant)
-    c = EVAL_BM_ACTION_BASE::parse_func_type(cmd);	// HSPICE style
-    parse_more_nodes(cmd, gotnodes);			// just a function
+    c = EVAL_BM_ACTION_BASE::parse_func_type(cmd);
+    parse_more_nodes(cmd, gotnodes);
   }
-  if (!c) {				// all nodes first
-    skip_dev_type(cmd); // (redundant)			// could be anything
+
+  // Normal mode.  nodes first, then data.
+  if (!c) {
+    skip_dev_type(cmd); // (redundant)
     c = new EVAL_BM_COND;	
   }
   assert(c);
+
   c->parse(cmd);
 
-  const COMPONENT_COMMON* dc = c->deflate(); // dc == deflated_common
-  const EVAL_BM_VALUE* dvc = dynamic_cast<const EVAL_BM_VALUE*>(dc);  
+  // At this point, there is ALWAYS a common attached, which may have more
+  // commons attached to it.  Try to reduce its complexity.
+  // "c->deflate()" may return "c" or some simplification of "c".
+  COMMON_COMPONENT* dc = c->deflate(); // dc == deflated_common
+  EVAL_BM_VALUE* dvc = dynamic_cast<EVAL_BM_VALUE*>(dc);  
   {if (dvc && !dvc->has_ext_args()) {
     set_value(dvc->value());
   }else{
@@ -204,7 +215,6 @@ XPROBE ELEMENT::ac_probe_ext(CS& cmd)const
       untested();
       return XPROBE(DBL_MAX);
     }else{
-      untested();
       return XPROBE(1. / admittance);
     }}
   }else if (cmd.pmatch("Z")) {			/* port impedance */
