@@ -1,4 +1,4 @@
-/*$Id: e_elemnt.h,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: e_elemnt.h,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * branch structure type definitions
  * device types (enumeration type?)
  */
@@ -23,7 +23,8 @@ protected: // override virtual
   void	   parse(CS&);
   void	   print(OMSTREAM&,int)const;
   bool	   tr_needs_eval()	{return !constant();}
-  void	   tr_queue_eval()	{if(tr_needs_eval()){q_eval();}}
+  void	   tr_queue_eval()	{if(tr_needs_eval()) {q_eval();}}
+  void	   map_nodes() {assert(!subckt().exists()); COMPONENT::map_nodes();}
   
 protected: // inline, below
   double   dampdiff(double&, const double&, bool);
@@ -32,8 +33,8 @@ protected: // inline, below
   void	   tr_unload_shunt();
   void	   ac_load_shunt();
 
-  void	   tr_load_loss() {tr_load_shunt();}
-  void	   ac_load_loss() {ac_load_shunt();}
+  void	   tr_load_loss();
+  void	   ac_load_loss();
 
   void	   tr_load_source();
   void	   tr_unload_source();
@@ -91,7 +92,7 @@ inline double ELEMENT::dampdiff(double& v0, const double& v1, bool damp)
 {
   //double diff = v0 - v1;
   double diff = dn_diff(v0, v1);
-  if (STATUS::iter[iSTEP] > 1 && damp){
+  if (STATUS::iter[iSTEP] > 1 && damp) {
     diff *= SIM::damp;
     v0 = v1 + diff;
   }
@@ -101,7 +102,7 @@ inline double ELEMENT::dampdiff(double& v0, const double& v1, bool damp)
 inline void ELEMENT::tr_load_shunt()
 {
   double d = dampdiff(_loss0, _loss1, true);
-  if (d != 0.){
+  if (d != 0.) {
     aa.load_symmetric(_n[OUT1].m, _n[OUT2].m, d);
   }
   _loss1 = _loss0;
@@ -110,7 +111,7 @@ inline void ELEMENT::tr_load_shunt()
 inline void ELEMENT::tr_unload_shunt()
 {
   _loss0 = 0.;
-  if (SIM::inc_mode){
+  if (SIM::inc_mode) {
     SIM::inc_mode = tsBAD;
   }
   tr_load_shunt();
@@ -120,6 +121,16 @@ inline void ELEMENT::ac_load_shunt()
 {
   acx.load_symmetric(_n[OUT1].m, _n[OUT2].m, _loss0);
 }
+/*--------------------------------------------------------------------------*/
+ inline void ELEMENT::tr_load_loss()
+{
+  tr_load_shunt();
+}
+/*--------------------------------------------------------------------------*/
+inline void ELEMENT::ac_load_loss()
+{
+  ac_load_shunt();
+}
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::tr_load_source()
 {
@@ -131,11 +142,11 @@ inline void ELEMENT::tr_load_source()
 #endif
 
   double dc0 = dampdiff(_m0.c0, _m1.c0, true);
-  if (dc0 != 0.){
-    if (_n[OUT2].m != 0){
+  if (dc0 != 0.) {
+    if (_n[OUT2].m != 0) {
       _n[OUT2].i() += dc0;
     }
-    if (_n[OUT1].m != 0){
+    if (_n[OUT1].m != 0) {
       _n[OUT1].i() -= dc0;
     }
   }
@@ -145,7 +156,7 @@ inline void ELEMENT::tr_load_source()
 inline void ELEMENT::tr_unload_source()
 {
   _m0.c0 = _m0.c1 = 0.;
-  {if (SIM::inc_mode){
+  {if (SIM::inc_mode) {
     SIM::inc_mode = tsBAD;
   }else{
     untested();
@@ -155,10 +166,10 @@ inline void ELEMENT::tr_unload_source()
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::ac_load_source()
 {
-  if (_n[OUT2].m != 0){
+  if (_n[OUT2].m != 0) {
     _n[OUT2].iac() += _acg;
   }
-  if (_n[OUT1].m != 0){
+  if (_n[OUT1].m != 0) {
     _n[OUT1].iac() -= _acg;
   }
 }
@@ -166,7 +177,7 @@ inline void ELEMENT::ac_load_source()
 inline void ELEMENT::tr_load_passive()
 {
   double d = dampdiff(_m0.c1, _m1.c1, true);
-  if (d != 0.){
+  if (d != 0.) {
     aa.load_symmetric(_n[OUT1].m, _n[OUT2].m, d);
   }
   tr_load_source();
@@ -175,7 +186,7 @@ inline void ELEMENT::tr_load_passive()
 inline void ELEMENT::tr_unload_passive()
 {
   _m0.c0 = _m0.c1 = 0.;
-  if (SIM::inc_mode){
+  if (SIM::inc_mode) {
     SIM::inc_mode = tsBAD;
   }
   tr_load_passive();
@@ -189,7 +200,7 @@ inline void ELEMENT::ac_load_passive()
 inline void ELEMENT::tr_load_active()
 {
   double d = dampdiff(_m0.c1, _m1.c1, true);
-  if (d != 0.){
+  if (d != 0.) {
     aa.load_asymmetric(_n[OUT1].m, _n[OUT2].m, _n[IN1].m, _n[IN2].m, d);
   }
   tr_load_source();
@@ -198,7 +209,7 @@ inline void ELEMENT::tr_load_active()
 inline void ELEMENT::tr_unload_active()
 {
   _m0.c0 = _m0.c1 = 0.;
-  {if (SIM::inc_mode){
+  {if (SIM::inc_mode) {
     SIM::inc_mode = tsBAD;
   }else{
     untested();
@@ -216,7 +227,7 @@ inline void ELEMENT::tr_load_extended(const node_t& no1, const node_t& no2,
 				      double* value, double* old_value)
 {
   double d = dampdiff(*value, *old_value, true);
-  if (d != 0.){
+  if (d != 0.) {
     aa.load_asymmetric(no1.m, no2.m, ni1.m, ni2.m, d);
   }
   *old_value = *value;
@@ -248,7 +259,7 @@ inline bool ELEMENT::has_ac_eval()const
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::tr_eval()
 {
-  {if (has_common() && common()->has_tr_eval()){
+  {if (has_common() && common()->has_tr_eval()) {
     common()->tr_eval(this);
   }else{
     // can get here if a simple device has probes
@@ -260,7 +271,7 @@ inline void ELEMENT::tr_eval()
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::ac_eval()
 {
-  {if (has_common() && common()->has_ac_eval()){
+  {if (has_common() && common()->has_ac_eval()) {
     common()->ac_eval(this);
   }else{
     // can get here if a simple device has probes
