@@ -1,4 +1,4 @@
-/*$Id: e_model.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: e_model.cc,v 19.6 2001/01/16 05:58:44 al Exp $ -*- C++ -*-
  * base class for all models
  */
 #include "ap.h"
@@ -31,7 +31,7 @@ void MODEL_CARD::parse(CS& cmd)
   }while (cmd.more() && !cmd.stuck(&here));
   cmd.skiprparen();
   cmd.check(bWARNING, "what's this?");
-  post_parse();
+  parse_finish();
 }
 /*--------------------------------------------------------------------------*/
 void MODEL_CARD::print(OMSTREAM& where, int)const
