@@ -1,4 +1,4 @@
-/*$Id: e_node.cc,v 18.18 2000/09/04 21:54:43 al Exp $ -*- C++ -*-
+/*$Id: e_node.cc,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * node probes
  */
 #include "l_denoise.h"
@@ -25,7 +25,7 @@ double volts_limited(const node_t & n1, const node_t & n2);
 /*--------------------------------------------------------------------------*/
 inline LOGICVAL& LOGICVAL::set_in_transition()
 {
-  switch (_lv){
+  switch (_lv) {
   case lvSTABLE0: _lv = lvRISING; break;
   case lvRISING:  untested(); break;
   case lvFALLING: untested(); break;
@@ -62,21 +62,21 @@ const std::string NODE::long_label()const
 /*--------------------------------------------------------------------------*/
 double NODE::tr_probe_num(CS& cmd)const
 {
-  {if (cmd.pmatch("V")){
+  {if (cmd.pmatch("V")) {
     return rint(v0()/OPT::vfloor) * OPT::vfloor;
-  }else if (cmd.pmatch("Z")){
+  }else if (cmd.pmatch("Z")) {
     return port_impedance(node_t(user_number()), node_t(0), lu, 0.);
-  }else if (cmd.pmatch("Logic")){
+  }else if (cmd.pmatch("Logic")) {
     return annotated_logic_value();
-  }else if (cmd.pmatch("LAstchange")){
+  }else if (cmd.pmatch("LAstchange")) {
     return _lastchange;
-  }else if (cmd.pmatch("FInaltime")){
+  }else if (cmd.pmatch("FInaltime")) {
     return final_time();
-  }else if (cmd.pmatch("DIter")){
+  }else if (cmd.pmatch("DIter")) {
     return static_cast<double>(_d_iter);
-  }else if (cmd.pmatch("AIter")){
+  }else if (cmd.pmatch("AIter")) {
     return static_cast<double>(_a_iter);
-  }else if (cmd.pmatch("COUNT")){
+  }else if (cmd.pmatch("COUNT")) {
     return static_cast<double>(_needs_analog);
   }else{
     untested();
@@ -86,9 +86,9 @@ double NODE::tr_probe_num(CS& cmd)const
 /*--------------------------------------------------------------------------*/
 XPROBE NODE::ac_probe_ext(CS& cmd)const
 {
-  {if (cmd.pmatch("V")){
+  {if (cmd.pmatch("V")) {
     return XPROBE(vac());
-  }else if (cmd.pmatch("Z")){
+  }else if (cmd.pmatch("Z")) {
     return XPROBE(port_impedance(node_t(user_number()),
 				 node_t(0),acx,COMPLEX(0.)));
   }else{
@@ -105,16 +105,17 @@ double NODE::annotated_logic_value()const
   return (_lv + (.1 * (OPT::transits - quality())) + (.01 * (2 - _mode)));
 }
 /*--------------------------------------------------------------------------*/
+static bool newly_stable[lvUNKNOWN+1][lvUNKNOWN+1] = { // oldlv, _lv
+  /*	   s0	  rise   fall	s1     u */
+  /* s0 */{false, false, false, true,  false},
+  /*rise*/{false, false, false, true,  false},
+  /*fall*/{true,  false, false, false, false},
+  /* s1 */{true,  false, false, false, false},
+  /* u  */{true,  false, false, true,  false}
+};
+/*--------------------------------------------------------------------------*/
 inline bool NODE::just_reached_stable()const
 {
-  static bool newly_stable[lvUNKNOWN+1][lvUNKNOWN+1] = { // oldlv, _lv
-    /*	     s0	    rise   fall	  s1	 u */
-    /* s0 */{false, false, false, true,  false},
-    /*rise*/{false, false, false, true,  false},
-    /*fall*/{true,  false, false, false, false},
-    /* s1 */{true,  false, false, false, false},
-    /* u  */{true,  false, false, true,  false}
-  };
   return newly_stable[_old_lv][_lv];
 }
 /*--------------------------------------------------------------------------*/
@@ -126,7 +127,7 @@ inline bool NODE::just_reached_stable()const
 NODE& NODE::to_logic(const MODEL_LOGIC* f)
 {
   assert(f);
-  if (_family && _family != f){
+  if (_family && _family != f) {
     untested();
     set_bad_quality("logic family mismatch");
     error(bWARNING, "node " + long_label() 
@@ -135,8 +136,8 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
   }
   _family = f;
 
-  if (is_analog() &&  _d_iter < _a_iter){
-    switch (SIM::phase){ // BUG:: hack to avoid crash on restart with t=0
+  if (is_analog() &&  _d_iter < _a_iter) {
+    switch (SIM::phase) { // BUG:: hack to avoid crash on restart with t=0
     case SIM::pDC_SWEEP:
     case SIM::pINIT_DC:	_lastchange=_old_lastchange=0;_lv=lvUNKNOWN;break;
     case SIM::pTRAN:	break;
@@ -144,11 +145,11 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
     }
 
     _dt = SIM::time0 - _lastchange;
-    {if (_dt < 0.){
+    {if (_dt < 0.) {
       error(bPICKY, "time moving backwards.  was %g, now %g\n",
 	    _lastchange, SIM::time0);
       _dt = SIM::time0 - _old_lastchange;
-      if (_dt <= 0.){
+      if (_dt <= 0.) {
 	untested();
 	error(bERROR,"internal error: time moving backwards, can't recover\n");
       }else{
@@ -162,8 +163,8 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
     }}
     
     double sv = v0() / _family->range;	/* new scaled voltage */
-    {if (sv >= _family->th1){		/* logic 1 */
-      switch (_lv){
+    {if (sv >= _family->th1) {		/* logic 1 */
+      switch (_lv) {
       case lvSTABLE0: dont_set_quality("stable 0 to stable 1");	break;
       case lvRISING:  dont_set_quality("begin stable 1");	break;
       case lvFALLING:untested();set_bad_quality("falling to stable 1"); break;
@@ -171,8 +172,8 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
       case lvUNKNOWN: set_good_quality("initial 1");		break;
       }
       _lv = lvSTABLE1;
-    }else if (sv <= _family->th0){	/* logic 0 */
-      switch (_lv){
+    }else if (sv <= _family->th0) {	/* logic 0 */
+      switch (_lv) {
       case lvSTABLE0: dont_set_quality("continuing stable 0");	break;
       case lvRISING: untested();set_bad_quality("rising to stable 0");	break;
       case lvFALLING: dont_set_quality("begin stable 0");	break;
@@ -183,11 +184,11 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
     }else{				/* transition region */
       double oldsv = vt1() / _family->range;/* old scaled voltage */
       double diff  = sv - oldsv;
-      {if (diff > 0){	/* rising */
-	switch (_lv){
+      {if (diff > 0) {	/* rising */
+	switch (_lv) {
 	case lvSTABLE0: dont_set_quality("begin good rise");		break;
 	case lvRISING:
-	  {if (diff < _dt/(_family->mr * _family->rise)){
+	  {if (diff < _dt/(_family->mr * _family->rise)) {
 	    set_bad_quality("slow rise");
 	  }else{
 	    dont_set_quality("continuing good rise");
@@ -198,12 +199,12 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
 	case lvUNKNOWN: set_bad_quality("initial rise");		break;
 	}
 	_lv = lvRISING;
-      }else if (diff < 0){	/* falling */
-	switch (_lv){
+      }else if (diff < 0) {	/* falling */
+	switch (_lv) {
 	case lvSTABLE0: set_bad_quality("positive glitch in 0");	break;
 	case lvRISING:  set_bad_quality("negative glitch in rise");	break;
 	case lvFALLING:
-	  {if (-diff < _dt/(_family->mf * _family->fall)){
+	  {if (-diff < _dt/(_family->mf * _family->fall)) {
 	    set_bad_quality("slow fall");
 	  }else{
 	    dont_set_quality("continuing good fall");
@@ -221,11 +222,11 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
 	/* state (rise/fall)  unchanged */
       }}
     }}
-    if (sv > 1.+_family->over || sv < -_family->over){/* out of range */
+    if (sv > 1.+_family->over || sv < -_family->over) {/* out of range */
       untested();
       set_bad_quality("out of range");
     }
-    if (just_reached_stable()){ /* A bad node gets a little better */
+    if (just_reached_stable()) { /* A bad node gets a little better */
       improve_quality();	/* on every good transition.	   */
     }				/* Eventually, it is good enough.  */
 				/* A good transition is defined as */
@@ -241,7 +242,7 @@ NODE& NODE::to_logic(const MODEL_LOGIC* f)
 double NODE::to_analog(const MODEL_LOGIC* f)
 {
   assert(f);
-  if (_family && _family != f){
+  if (_family && _family != f) {
     untested();
     error(bWARNING, "node " + long_label() 
 	  + " logic family mismatch\nis it " + _family->long_label() 
@@ -252,7 +253,7 @@ double NODE::to_analog(const MODEL_LOGIC* f)
   double start = NOT_VALID;
   double end = NOT_VALID;
   double risefall = NOT_VALID;
-  switch (_lv){
+  switch (_lv) {
   case lvSTABLE0: return _family->vmin;
   case lvRISING:  untested(); 
     start=_family->vmin; end=_family->vmax; risefall=_family->rise; break;
@@ -265,9 +266,9 @@ double NODE::to_analog(const MODEL_LOGIC* f)
   assert(end   != NOT_VALID);
   assert(risefall != NOT_VALID);
 
-  {if (SIM::time0 <= (final_time()-risefall)){
+  {if (SIM::time0 <= (final_time()-risefall)) {
     return start;
-  }else if (SIM::time0 >= final_time()){
+  }else if (SIM::time0 >= final_time()) {
     untested();
     return end;
   }else{
@@ -278,9 +279,9 @@ double NODE::to_analog(const MODEL_LOGIC* f)
 NODE& NODE::propagate()
 {
   assert(in_transit());
-  {if (_lv.is_rising()){
+  {if (_lv.is_rising()) {
     _lv = lvSTABLE1;
-  }else if (_lv.is_falling()){
+  }else if (_lv.is_falling()) {
     _lv = lvSTABLE0;
   }else{
     //untested();
@@ -307,7 +308,7 @@ NODE& NODE::force_initial_value(LOGICVAL v)
 NODE& NODE::set_event(double delay)
 {
   _lv.set_in_transition();
-  if (SIM::phase == SIM::pTRAN  &&  in_transit()){ 
+  if (SIM::phase == SIM::pTRAN  &&  in_transit()) { 
     untested();
     set_bad_quality("race");
   }
@@ -330,26 +331,40 @@ OMSTREAM& operator<<(OMSTREAM& o, const node_t& n)
  */
 double volts_limited(const node_t & n1, const node_t & n2)
 {
-#if 1
-  double v1 = torange(CKT_BASE::_vmin, n1.v0(), CKT_BASE::_vmax);
-  double v2 = torange(CKT_BASE::_vmin, n2.v0(), CKT_BASE::_vmax);
-  double vdiff = dn_diff(v1,v2);
-#else
-  double v1 = torange(OPT::vmin, n1.v0(), OPT::vmax);
-  double v2 = torange(OPT::vmin, n2.v0(), OPT::vmax);
-  double vdiff = torange(-OPT::limit, dn_diff(v1,v2), OPT::limit);
-#endif
-  if (OPT::dampstrategy & dsRANGE
-  	&& (abs(vdiff - (n1.v0() - n2.v0())) > OPT::abstol)){
-    SIM::fulldamp = true;
-    error(bTRACE, "range limit damp\n");
+  bool limiting = false;
+
+  double v1 = n1.v0();
+  {if (v1 < CKT_BASE::_vmin) {
+    limiting = true;
+    v1 = CKT_BASE::_vmin;
+  }else if (v1 > CKT_BASE::_vmax) {
+    limiting = true;
+    v1 = CKT_BASE::_vmax;
+  }}
+
+  double v2 = n2.v0();
+  {if (v2 < CKT_BASE::_vmin) {
+    limiting = true;
+    v2 = CKT_BASE::_vmin;
+  }else if (v2 > CKT_BASE::_vmax) {
+    limiting = true;
+    v2 = CKT_BASE::_vmax;
+  }}
+
+  if (limiting) {
+    SIM::limiting = true;
+    if (OPT::dampstrategy & dsRANGE) {
+      SIM::fulldamp = true;
+      error(bTRACE, "range limit damp\n");
+    }
+    if (OPT::picky <= bTRACE) {
+      error(bNOERROR,"node limiting (n1,n2,dif) "
+	    "was (%g %g %g) now (%g %g %g)\n",
+	    n1.v0(), n2.v0(), n1.v0() - n2.v0(), v1, v2, v1-v2);
+    }
   }
-  if (OPT::picky <= bTRACE
-  	&& (abs(vdiff - (n1.v0() - n2.v0())) > OPT::abstol)){
-    error(bNOERROR,"node limiting (n1,n2,dif) was (%g %g %g) now (%g %g %g)\n",
-     	 n1.v0(), n2.v0(), n1.v0() - n2.v0(), v1, v2, vdiff);
-  }
-  return vdiff;
+
+  return dn_diff(v1,v2);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
