@@ -1,4 +1,4 @@
-/*$Id: e_node.h,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: e_node.h,v 19.16 2001/04/28 01:08:30 al Exp $ -*- C++ -*-
  * circuit node class
  */
 #ifndef E_NODE_H
@@ -33,10 +33,11 @@ private:
   LOGICVAL(int p) :_lv(p)			{fix();}
 public:
   LOGICVAL() :_lv(lvUNKNOWN)			{}
-  LOGICVAL(const LOGICVAL& p) :_lv(p._lv)	{}
-  LOGICVAL(const _LOGICVAL& p) :_lv(p)		{}
+  LOGICVAL(const LOGICVAL& p)	:_lv(p._lv)	{}
+  LOGICVAL(_LOGICVAL p)		:_lv(p)		{}
 
-  LOGICVAL& operator=(const LOGICVAL& p){_lv=p._lv;return *this;}
+  LOGICVAL& operator=(_LOGICVAL p)	{_lv=p; return *this;}
+  LOGICVAL& operator=(const LOGICVAL& p){_lv=p._lv; return *this;}
   LOGICVAL& operator&=(LOGICVAL p) {untested(); _lv &= p._lv; return fix();}
   LOGICVAL& operator|=(LOGICVAL p) {untested(); _lv |= p._lv; return fix();}
   LOGICVAL operator~()const {return (_lv==lvUNKNOWN) ?lvUNKNOWN :((~_lv)&3);}
@@ -105,7 +106,6 @@ public:
   static int  to_internal(int i)	{return SIM::nm[i];}
 private:
   double      v0()const			{return SIM::v0 [internal_number()];}
-  double      vi1()const		{return SIM::vi1[internal_number()];}
   double      vt1()const		{return SIM::vt1[internal_number()];}
   double      vdc()const		{return SIM::vdc[internal_number()];}
   COMPLEX     vac()const		{return SIM::ac [internal_number()];}
@@ -162,8 +162,6 @@ public:
   NODE*	      operator->()const
     {assert(is_valid());extern NODE*nstat;assert(nstat);return&(nstat[m]);}
   double      v0()const			{return SIM::v0[m];}	/* rvalues */
-  double      vi1()const		{return SIM::vi1[m];}
-  double      vt1()const		{untested(); return SIM::vt1[m];}
   double      vdc()const		{return SIM::vdc[m];}
   COMPLEX     vac()const		{return SIM::ac[m];}
   double&     i()			{return SIM::i[m];}	/* lvalues */
