@@ -1,4 +1,4 @@
-/*$Id: e_subckt.h,v 16.15 1999/12/20 09:18:34 al Exp $ -*- C++ -*-
+/*$Id: e_subckt.h,v 19.3 2000/11/30 01:09:48 al Exp $ -*- C++ -*-
  * base class for elements made of subcircuits
  */
 #ifndef E_SUBCKT_H
@@ -9,7 +9,15 @@ class BASE_SUBCKT : public COMPONENT {
 protected:
   explicit BASE_SUBCKT()		     :COMPONENT() {}
   explicit BASE_SUBCKT(const BASE_SUBCKT& p) :COMPONENT(p){}
-private: // override virtual
+protected: // override virtual
+  //char  id_letter()const		//CARD/null
+  //const char* dev_type()const		//COMPONENT/null
+  //int	  numnodes()const		//COMPONENT/null
+  //CARD* clone()const			//CARD/null
+  //void  parse(CS&)			//CARD/null
+  //void  print(OMSTREAM&,int)const	//CARD/null
+  void	  expand()	{subckt().expand();}
+  void	  map_nodes()	{COMPONENT::map_nodes(); subckt().map_nodes();}
   void	  precalc()	{subckt().precalc();}
   void	  dc_begin()	{subckt().dc_begin();}
   void	  tr_begin()	{subckt().tr_begin();}
