@@ -1,4 +1,4 @@
-/*$Id: io_contr.cc,v 18.4 2000/07/09 05:58:31 al Exp $ -*- C++ -*-
+/*$Id: io_contr.cc,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
  * Sets up output direction and format for most commands
  * updates pointers into the string
  * outreset starts it all over
@@ -6,7 +6,7 @@
 #include "io_.h"
 #include "ap.h"
 /*--------------------------------------------------------------------------*/
-	void	initio(OMSTREAM&,FILE*);
+	void	initio(OMSTREAM&);
 	void	decipher(char*);
 	void	outreset(void);
 	OMSTREAM* outset(CS&,OMSTREAM*);
@@ -16,11 +16,12 @@ static FILE *fn;		/* write file				    */
 /*--------------------------------------------------------------------------*/
 /* initio: initialize file encryption, etc
  */
-void initio(OMSTREAM& Where, FILE *Whence)
+void initio(OMSTREAM& Where)
 {
   const char* tag = "''''";
   if (Where.cipher())			/* if writing an encrypted file,    */
     Where << tag << '\n';		/* mark it as encrypted		    */
+#if 0
   if (Whence){
     char buf[BUFLEN];
     if (!fgets(buf, BUFLEN, Whence))	/* if the first line deciphers to   */
@@ -32,6 +33,7 @@ void initio(OMSTREAM& Where, FILE *Whence)
       fseek(Whence,0L,SEEK_SET);
     }
   }
+#endif
 }
 /*--------------------------------------------------------------------------*/
 /* decipher: un-encrypt a line of text in place
@@ -55,7 +57,6 @@ void decipher(char *buf)
 void outreset(void)
 {
   xclose(&fn);
-  xclose(&IO::whence);
   IO::formaat = 0;
   IO::incipher = false;
   IO::mstdout.reset();
@@ -66,7 +67,6 @@ void outreset(void)
  */
 OMSTREAM* outset(CS& cmd, OMSTREAM* out)
 {
-  bool retcode = false;
   for (;;){
     if (cmd.pmatch("Basic")){
       IO::formaat = ftos_EXP;
@@ -76,25 +76,22 @@ OMSTREAM* outset(CS& cmd, OMSTREAM* out)
     }else if (cmd.pmatch("Pack")){
       (*out).setpack();
     }else if (cmd.pmatch("Quiet")){
-      (*out) &= ~IO::mstdout;
+      (*out).detach(IO::mstdout);
     }else if (cmd.pmatch("Echo") || cmd.pmatch("List")){
-      (*out) |= IO::mstdout;
+      (*out).attach(IO::mstdout);
     }else if (cmd.pmatch("SAve")){
       fn = file_open(cmd,"","w",fn);
-      (*out) |= OMSTREAM(fn);
+      (*out).attach(fn);
     }else if (cmd.pmatch(">$$")){
       const char *rwaflag;
       rwaflag = (cmd.pmatch(">$$")) ? "a" : "w";
       fn = file_open(cmd,"",rwaflag,fn);
-      (*out) |= OMSTREAM(fn);
+      (*out).attach(fn);
       IO::formaat = ftos_EXP;
       (*out).setformat(ftos_EXP);
-    }else if (cmd.pmatch("<$$")){
-      IO::whence = file_open(cmd,"","r",IO::whence);
     }else{
       break;
     }
-    retcode = true;
   }
   return out;
 }
