@@ -1,4 +1,4 @@
-/*$Id: io_xopen.cc,v 18.4 2000/07/09 05:58:31 al Exp $ -*- C++ -*-
+/*$Id: io_xopen.cc,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * scan a string for a file name
  * fill in extension, if necessary
  * open file
@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 void xclose(FILE **fn)
 {
-  if (*fn){
+  if (*fn) {
     fclose(*fn);
     *fn = NULL;
   }
@@ -34,33 +34,33 @@ FILE *xopen(CS& cmd, const char *ext, const char *how)
   char fname[BIGBUFLEN];
   
   cmd.skipbl();
-  if (cmd.end()){
+  if (cmd.end()) {
     cmd = getcmd("file name?  ",fname, BIGBUFLEN);
   }
 					/* copy the name		    */
 					/* and while we're at it ...	    */
   cmd.skipbl();				/* find out if we want to add the   */
   defalt = true;			/* default extension		    */
-  for (i = 0;   i < BIGBUFLEN;   ){
+  for (i = 0;   i < BIGBUFLEN;   ) {
     char c = cmd.ctoc();
-    if (!c || isspace(c)){
+    if (!c || isspace(c)) {
       break;
     }
-    {if (c == '$'){
+    {if (c == '$') {
       untested(); 
-      sprintf(&(fname[i]), "%ld", static_cast<long>(time((time_t*)NULL)));
+      sprintf(&(fname[i]), "%ld", static_cast<long>(time(0)));
       i = strlen(fname);
     }else{				/* we want to add the extension	    */
       fname[i++] = c;			/* if it doesn't already have one,  */
-      {if (c == '.'){			/* as determined by a '.'	    */
+      {if (c == '.') {			/* as determined by a '.'	    */
 	defalt = false;			/* not before the directory	    */
-      }else if (strchr(ENDDIR,c)){	/* separator-terminator character   */
+      }else if (strchr(ENDDIR,c)) {	/* separator-terminator character   */
 	defalt = true;			/* '\' or '/' for msdos,	    */
       }}
     }}  				/* ']' or '/' for vms,		    */
   }					/* '/' for unix  (in ENDDIR)	    */
   cmd.skip(-1);
-  {if (defalt && ext && *ext && i+strlen(ext)+2 < BIGBUFLEN){
+  {if (defalt && ext && *ext && i+strlen(ext)+2 < BIGBUFLEN) {
     untested(); 
     fname[i++] = '.';			/* add the extension (maybe)	    */
     strcpy(&fname[i],ext);
@@ -69,17 +69,17 @@ FILE *xopen(CS& cmd, const char *ext, const char *how)
   }}
   
   trim(fname);
-  if (strlen(fname)==0){
+  if (strlen(fname)==0) {
     return NULL;
   }
 
   cmd.skipcom();
   
-  {if ((*how == 'w')   &&   (access(fname,F_OK) == FILE_OK)){
+  {if ((*how == 'w')   &&   (access(fname,F_OK) == FILE_OK)) {
     char buffer[BUFLEN];		
     error(bWARNING, "%s exists.  replace? ", fname);
     getcmd("", buffer, BUFLEN);
-    {if (pmatch(buffer,"Yes")){		/* should be new file, but	    */
+    {if (pmatch(buffer,"Yes")) {	/* should be new file, but	    */
       code = fopen(fname,how);		/* file already exists,  ask	    */
     }else{
       return NULL;
@@ -88,13 +88,13 @@ FILE *xopen(CS& cmd, const char *ext, const char *how)
     code = fopen(fname,how);
   }}
   
-  if (code && fileno(code)>MAXHANDLE){
+  if (code && fileno(code)>MAXHANDLE) {
     untested(); 
     error(bWARNING, "internal error: files: %d\n", fileno(code));
     fclose(code);
     code = NULL;
   }
-  {if (code){
+  {if (code) {
     IO::stream[static_cast<int>(fileno(code))] = code;
   }else{
     error(bWARNING, "can't open %s, %s\n", fname, strerror(errno));
