@@ -1,4 +1,4 @@
-/*$Id: l_compar.h,v 14.18 1999/08/16 02:43:02 al Exp $ -*- C++ -*-
+/*$Id: l_compar.h,v 19.4 2001/01/13 21:33:15 al Exp $ -*- C++ -*-
  * inline utility functions, general purpose
  */
 #ifndef L_UTIL_H
@@ -6,15 +6,18 @@
 #include "md.h"
 /*--------------------------------------------------------------------------*/
 /* uporder: returns true if a,b,c are in non-decreasing order */
-inline bool uporder(double a, double b, double c)
+template <class T>
+inline bool up_order(T a, T b, T c)
    {return (a<=b) && (b<=c);}
 
 /* inorder: returns true if b is between a and c */
-inline bool inorder(double a, double b, double c)
-   {return uporder(a,b,c) || uporder(c,b,a);}
+template <class T>
+inline bool in_order(T a, T b, T c)
+   {return up_order(a,b,c) || up_order(c,b,a);}
 
 /* torange: returns b, clipped to range a..c */
-inline double torange(double a, double b, double c)
+template <class T>
+inline T to_range(T a, T b, T c)
    {return std::min(std::max(a,b),c);}
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
