@@ -1,4 +1,4 @@
-/*$Id: l_denoise.h,v 13.34 1999/05/03 08:18:39 al Exp $ -*- C++ -*-
+/*$Id: l_denoise.h,v 17.22 2000/05/12 10:31:53 al Exp $ -*- C++ -*-
  * functions to "de-noise" arithmetic
  * attempt to get rid of noise due to roundoff
  */
@@ -8,19 +8,29 @@
 /*--------------------------------------------------------------------------*/
 /* fixzero: force numbers near zero to zero - changes thru pointer */
 inline void fixzero(double *z, double r)
-   {if (fabs(*z) < fabs(r*OPT::roundofftol)) *z=0.;}
-
+{
+  if (abs(*z) < abs(r*OPT::roundofftol)) {
+    *z=0.;
+  }
+}
+/*--------------------------------------------------------------------------*/
 /* fixzero: force numbers near zero to zero - returns value */
 inline double fixzero(double z, double r)
-   {return (fabs(z) < fabs(r*OPT::roundofftol)) ? 0. : z;}
-
+{
+  return (abs(z) < abs(r*OPT::roundofftol)) ? 0. : z;
+}
+/*--------------------------------------------------------------------------*/
 /* dn_diff: de-noised difference */
 inline double dn_diff(double a, double b)
-   {return fixzero(a-b, a);}
-
+{
+  return fixzero(a-b, a);
+}
+/*--------------------------------------------------------------------------*/
 /* dn_sum: de-noised sum */
 inline double dn_sum(double a, double b)
-   {return fixzero(a+b, a);}
+{
+  return fixzero(a+b, a);
+}
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
 #endif
