@@ -1,4 +1,4 @@
-/*$Id: l_lib.h,v 18.9 2000/08/16 08:11:43 al Exp $ -*- C++ -*-
+/*$Id: l_lib.h,v 19.12 2001/02/24 03:40:45 al Exp $ -*- C++ -*-
  */
 #ifndef L_LIB_H
 #define L_LIB_H
@@ -10,10 +10,6 @@
 /*--------------------------------------------------------------------------*/
 //ftos stuff
 	char*	ftos(double,int,int,int);
-	void	ftos_set_floor(double);
-	int	ftos_set_format(int);
-	int	ftos_set_precision(int);
-	int	ftos_set_width(int);
 enum {			/* formatting bit-fields */
   ftos_DEFAULT = 0,	/* default formatting, with letters */
   ftos_EXP = 1,		/* use 'e' notation, almost like printf */
@@ -26,7 +22,6 @@ inline bool wmatch(const std::string& s1,const char* s2){
   return wmatch(s1.c_str(), s2);
 }
 inline bool wmatch(const std::string& s1,const std::string& s2){
-  untested();
   return wmatch(s1.c_str(), s2.c_str());
 }
 /*--------------------------------------------------------------------------*/
