@@ -1,11 +1,10 @@
-/*$Id: l_stlextra.h,v 18.4 2000/07/09 05:58:31 al Exp $ -*- C++ -*-
+/*$Id: l_stlextra.h,v 19.17 2001/04/28 22:47:17 al Exp $ -*- C++ -*-
  * extra functions in the STL style
  * Things that ought to be there, but are not
  */
 #ifndef L_STLEXTRA_H
 #define L_STLEXTRA_H
-/*--------------------------------------------------------------------------*/
-//InputIterator find_ptr(InputIterator first,InputIterator last,const T& value)
+#include "md.h"
 /*--------------------------------------------------------------------------*/
 /* find_ptr: like the stl find, except that the list contains pointers
    Dereference the pointer in the list, then compare */
@@ -17,5 +16,13 @@ InputIterator find_ptr(InputIterator first,InputIterator last,const T& value)
   return first;
 }
 /*--------------------------------------------------------------------------*/
+inline void to_lower(std::string* s)
+{
+  assert(s);
+  for (std::string::iterator i = s->begin(); i != s->end(); ++i) {
+    *i = tolower(*i);
+  }
+}
+/*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
 #endif
