@@ -1,4 +1,4 @@
-/*$Id: l_timer.cc,v 16.5 1999/11/25 07:56:24 al Exp $	-*- C++ -*-
+/*$Id: l_timer.cc,v 19.25 2001/06/15 21:09:29 al Exp $	-*- C++ -*-
  * Time a command, or whatever
  */
 /*--------------------------------------------------------------------------*/
@@ -56,16 +56,18 @@ TIMER& TIMER::zstart()
 TIMER& TIMER::start()
 {
   assert(!_running);
-  if (_running){
+  if (_running) {
     untested();
     stop();
   }
   struct rusage x;
   getrusage(RUSAGE_SELF,&x);
   _ref_user =
-    (double)(x.ru_utime.tv_sec) + (double)(x.ru_utime.tv_usec)*1e-6; 
+    static_cast<double>(x.ru_utime.tv_sec)
+    + static_cast<double>(x.ru_utime.tv_usec)*1e-6; 
   _ref_system =
-    (double)(x.ru_stime.tv_sec) + (double)(x.ru_stime.tv_usec)*1e-6; 
+    static_cast<double>(x.ru_stime.tv_sec)
+    + static_cast<double>(x.ru_stime.tv_usec)*1e-6; 
   _running = true;
 
   return *this;
@@ -73,12 +75,13 @@ TIMER& TIMER::start()
 /*--------------------------------------------------------------------------*/
 TIMER& TIMER::stop()
 {
-  if (_running){
+  if (_running) {
     struct rusage x;
     getrusage(RUSAGE_SELF,&x);
     {
       double utime =
-	(double)(x.ru_utime.tv_sec)+(double)(x.ru_utime.tv_usec)*1e-6; 
+	static_cast<double>(x.ru_utime.tv_sec)
+	+ static_cast<double>(x.ru_utime.tv_usec)*1e-6; 
       double runtime = utime - _ref_user;
       _ref_user	  =  0.;
       _last_user  += runtime;
@@ -86,7 +89,8 @@ TIMER& TIMER::stop()
     }
     {
       double stime =
-	(double)(x.ru_stime.tv_sec)+(double)(x.ru_stime.tv_usec)*1e-6; 
+	static_cast<double>(x.ru_stime.tv_sec)
+	+ static_cast<double>(x.ru_stime.tv_usec)*1e-6; 
       double runtime = stime - _ref_system;
       _ref_system   =  0.;
       _last_system  += runtime;
@@ -99,7 +103,7 @@ TIMER& TIMER::stop()
 /*--------------------------------------------------------------------------*/
 TIMER& TIMER::check()
 {
-  if (_running){
+  if (_running) {
     stop();
     start();
   }
