@@ -1,4 +1,4 @@
-/*$Id: m_fft.cc,v 13.15 1999/01/18 06:29:03 al Exp $ -*- C++ -*-
+/*$Id: m_fft.cc,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
  * fast fourier transform
  */
 #include "constant.h"
@@ -29,7 +29,7 @@ void fft(COMPLEX *x, int n, int inv)
   /* unscramble */
   {
     int i, j, k;
-    for (k = i = j = 0;  i < n-1;  i++, j += k){
+    for (/*k =*/ i = j = 0;  i < n-1;  i++, j += k){
       if (i < j){
 	COMPLEX t = x[j];
 	x[j] = x[i];
