@@ -1,13 +1,11 @@
-/*$Id: md.h,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: md.h,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
  * Machine dependent, configuration, and standard includes
  */
 #ifndef MD_H_INCLUDED
 #define MD_H_INCLUDED
 /*--------------------------------------------------------------------------*/
 /* system dependent patches needed before the standard includes */
-#if defined(__GNUG__)
-  #define __HONOR_STD
-#elif defined (WIN32)
+#if defined (WIN32)
   #pragma warning (disable: 4786) // id truncated to 255 characters
   #pragma warning (disable: 4800) // forcing ___ to bool (performance warning)
   #pragma warning (disable: 4660) // template already instantiated
@@ -41,7 +39,13 @@
 #include <typeinfo>
 #include <algorithm>
 /*--------------------------------------------------------------------------*/
-#if defined(UNIX)
+/* constants related to memory size, word size, etc */
+enum {
+  BUFLEN = 256,
+  BIGBUFLEN = 2048
+};
+/*--------------------------------------------------------------------------*/
+#if defined(__unix__)
 /* usual but non-standard collection of includes */
 #include <unistd.h>	  /* chdir, access, getcwd */
 #include <sys/time.h>	  /* struct timeval, may be needed by sys/resource */
@@ -56,14 +60,8 @@
 #define STEPFILE   	"/tmp/SXXXXXX"
 #define PLOTFILE    	"acs.plot"
 #define SHELL		OS::getenv("SHELL")
-/* constants related to memory size, word size, etc */
-enum {
-  BUFLEN = 256,
-  BIGBUFLEN = 2048
-};
 /* machine and compiler patches */
-#define CONST const
-#if defined(SUN)
+#if defined(__sun__)
   #define NEEDS_IS_INF
 #endif
 #if defined(__GNUG__)
@@ -74,11 +72,12 @@ enum {
   #define __FUNCTION__ ""
   #define NEW_IS_BROKEN
   #define NEEDS_COPY_N
-  #define BROKEN_CONST_FOLD
-  #define BROKEN_TEMPLATE_OVERLOAD
+  #define DBL_MAX_IS_VARIABLE
+#else
+  #error what compiler are you using??
 #endif
 /*--------------------------------------------------------------------------*/
-#elif defined(WIN32)
+#elif defined(__WIN32__)
 /* usual but non-standard collection of includes */
 #include <windows.h>
 #include <io.h>
@@ -94,58 +93,43 @@ enum {
 #define STEPFILE   	"/tmp/SXXXXXX"
 #define PLOTFILE    	"acs.plot"
 #define SHELL		OS::getenv("COMSPEC")
-/* constants related to memory size, word size, etc */
-enum {
-  BUFLEN = 256,
-  BIGBUFLEN = 2048
-};
 /* machine and compiler patches */
 #define MANUAL_TEMPLATES
 #define NEEDS_COPY_N
 #define NEEDS_GETRUSAGE
+#define NEEDS_RINT
 #define NEW_IS_BROKEN
 #define ABS_IS_BROKEN
-#define SIGNALARGS int
-#undef  CONST
-#define CONST
-#define F_OK (00)		/* io.h */
-#define X_OK (01)
-#define W_OK (02)
-#define R_OK (04)
-#define MAXPATHLEN (1024)
-#define RUSAGE_SELF	0
-#define sigjmp_buf jmp_buf
-#define siglongjmp(a,b) longjmp(a,b)
-#define sigsetjmp(a,b) setjmp(a)
-#define PATH_MAX 1024
-#undef min
-#undef max
-namespace std{
-  template <class T>
-  inline const T& min(const T& a, const T& b) {
-    return b < a ? b : a;
-  }
-  template <class T>
-  inline const T& max(const T& a, const T& b) {
-    return  a < b ? b : a;
-  }
-}
+#define SIGSETJMP_IS_BROKEN
+enum {F_OK=0, X_OK=1, W_OK=2, R_OK=4};
 inline int strcasecmp(const char a[], const char b[]){
   return stricmp(a,b);
 }
-inline int isinf(double x){
-  if (_fpclass(x) == _FPCLASS_PINF){
-    return 1;
-  }else if (_fpclass(x) == _FPCLASS_NINF){
-    return -1;
-  }else{
-    return 0;
-  }
-}
-inline int isnan(double x){
-  return _isnan(x);
-}
 const char __FUNCTION__[] = "";
+#if defined(__BORLANDC__)
+  #include <setjmp.h>
+  typedef int off_t;
+  #define NEEDS_IS_INF
+  #define NEEDS_IS_NAN
+  #define DBL_MAX_IS_VARIABLE
+#elif defined(MICROSOFT)
+  #define MIN_MAX_IS_BROKEN
+  #define CONST_IS_BROKEN
+  inline int isinf(double x){
+    if (_fpclass(x) == _FPCLASS_PINF){
+      return 1;
+    }else if (_fpclass(x) == _FPCLASS_NINF){
+      return -1;
+    }else{
+      return 0;
+    }
+  }
+  inline int isnan(double x){
+    return _isnan(x);
+  }
+#else
+  #error what compiler are you using??
+#endif
 /*--------------------------------------------------------------------------*/
 #else
 #error what kind of system is this??
@@ -202,6 +186,10 @@ namespace std {
   inline int isnan(double x) {untested(); return (x != x);}
 #endif
 
+#if defined(NEEDS_RINT)
+  inline double rint(double x) {untested(); return (floor(x+.5));}
+#endif
+
 #if defined(ABS_IS_BROKEN)
   inline double abs(double x) {return fabs(x);}
 #endif
@@ -212,6 +200,41 @@ struct	rusage {
   struct timeval ru_stime;	/* system time used */
 };
 int getrusage(int,struct rusage*);
+#define RUSAGE_SELF	0
+#endif
+
+#if defined(MIN_MAX_IS_BROKEN)
+  #undef min
+  #undef max
+  namespace std{
+    template <class T>
+    inline const T& min(const T& a, const T& b) {
+      return b < a ? b : a;
+    }
+    template <class T>
+    inline const T& max(const T& a, const T& b) {
+      return  a < b ? b : a;
+    }
+  }
+#endif
+
+#if defined(DBL_MAX_IS_VARIABLE)
+  #undef DBL_MAX
+  #define DBL_MAX (1e300)
+#endif
+
+#if defined(SIGSETJMP_IS_BROKEN)
+  #define sigjmp_buf jmp_buf
+  #define siglongjmp(a,b) longjmp(a,b)
+  #define sigsetjmp(a,b) setjmp(a)
+#endif
+
+#if defined(CONST_IS_BROKEN)
+  #undef  CONST
+  #define CONST
+#else
+  #undef  CONST
+  #define CONST const
 #endif
 
 #if !defined(SIGNALARGS)
