@@ -1,4 +1,4 @@
-/*$Id: plot.cc,v 18.4 2000/07/09 05:58:31 al Exp $
+/*$Id: plot.cc,v 19.25 2001/06/15 21:09:29 al Exp $
  * (this file is a mess.  it should be redone.)
  */
 #include "u_opt.h"
@@ -43,16 +43,16 @@ static struct graph *c;
 /*--------------------------------------------------------------------------*/
 void plottr(double xx)              /* plot a data point,  transient        */
 {
-  if (active){
+  if (active) {
     int ii = 0;
     double lo[2] = {0.};
     double hi[2] = {0.};
     double val[2] = {0.};
     
     for (PROBELIST::const_iterator i=PROBE_LISTS::plot[SIM::mode].begin();
-	 i!=PROBE_LISTS::plot[SIM::mode].end(); ++i){
+	 i!=PROBE_LISTS::plot[SIM::mode].end(); ++i) {
       val[ii] = i->value();
-      if (i->range() != 0.){
+      if (i->range() != 0.) {
 	lo[ii] = i->lo();
 	hi[ii] = i->hi();
       }else{
@@ -63,7 +63,7 @@ void plottr(double xx)              /* plot a data point,  transient        */
       if (ii >= 2)
 	break;
     }
-    if (ii <= 1){
+    if (ii <= 1) {
       val[1] = NOT_VALID;
     }
     plotarg(xx, val[0], val[1],
@@ -81,7 +81,7 @@ int plopen(int mode, double start, double stop, bool linswp)
   if (start == stop)
     IO::plotout = OMSTREAM();
   device = (testcrt()) ? "CRt" : "Ascii" ;
-  if (!IO::plotout.any()){
+  if (!IO::plotout.any()) {
     plclear();
     return false;
   }
@@ -104,12 +104,12 @@ int plopen(int mode, double start, double stop, bool linswp)
  */
 void plclose(void)
 {
-  if (!active){
+  if (!active) {
     return;
   }
-  if (*device=='C'){
+  if (*device=='C') {
     (*c->fin)();                    /* usually a stub, except for Hercules  */
-  }else if (*device=='A'){
+  }else if (*device=='A') {
     plborder();
   }else{
     error(bWARNING, "internal error: plclose\n" );
@@ -123,7 +123,7 @@ void plclose(void)
 void plclear(void)
 {
   active = false;
-  if (crtplot){
+  if (crtplot) {
     crtplot = false;
     (*c->can)();
   }
@@ -134,7 +134,7 @@ void plclear(void)
  */
 void pllocate(void)
 {
-  if (crtplot){
+  if (crtplot) {
     stext( 0, c->wh+2*c->lpc, "", c->pri);
   }
 }
@@ -160,7 +160,7 @@ static void calibrate(const PROBE& prb)
   double markno;		/* loop counter                             */
  
   double hi, lo;
-  if (prb.range() == 0){
+  if (prb.range() == 0) {
     hi = 5;
     lo = -5;
   }else{
@@ -177,9 +177,9 @@ static void calibrate(const PROBE& prb)
   IO::plotout << prb.label();
   range = hi - lo;
   filled = 0;
-  for (markno = 0.;  markno < OPT::ydivisions;  markno++){
+  for (markno = 0.;  markno < OPT::ydivisions;  markno++) {
     double number = lo + range * markno/OPT::ydivisions ;
-    if (abs(number) < abs(range)/(10.*CONSSCALE)){
+    if (abs(number) < abs(range)/(10.*CONSSCALE)) {
       number = 0.;
     }			    		       /* label to put on this div. */
     strcpy(nums, ftos(number, 0, 5, IO::formaat));
@@ -187,7 +187,7 @@ static void calibrate(const PROBE& prb)
     numsize = strlen(nums);			 /* center it over the mark */
     cal = round(INDENT + CONSSCALE * (markno/OPT::ydivisions));
     start = cal - (numsize+1)/2;
-    if (start > filled  &&  start+numsize < stop){
+    if (start > filled  &&  start+numsize < stop) {
       IO::plotout.tab(start) << nums;		 /* if it fits, print it */
       filled = start + numsize ;
     }
@@ -197,7 +197,7 @@ static void calibrate(const PROBE& prb)
 /*--------------------------------------------------------------------------*/
 static int round(double x)
 {
-  return (int)floor(x+.5);
+  return static_cast<int>(floor(x+.5));
 }
 /*--------------------------------------------------------------------------*/
 /* plhead: begin ascii graphics
@@ -206,15 +206,16 @@ static int round(double x)
 static void plhead(void)
 {
   for (PROBELIST::const_iterator i=PROBE_LISTS::plot[SIM::mode].begin();
-       i!=PROBE_LISTS::plot[SIM::mode].end(); ++i){
+       i!=PROBE_LISTS::plot[SIM::mode].end(); ++i) {
     calibrate(*i);
   }
-  for (int ii = 0;  ii < CONSSCALE; ii++){		/* build strings */
+  for (int ii = 0;  ii < CONSSCALE; ii++) {		/* build strings */
     border[ii] = '-';
     emptydata[ii] = ' ';
   }
-  double incr = (double)CONSSCALE / OPT::ydivisions;
-  for (double place = 0.;   place < (double)CONSSCALE;   place += incr){
+  double incr = static_cast<double>(CONSSCALE) / OPT::ydivisions;
+  for (double place = 0.;   place < static_cast<double>(CONSSCALE);
+       place += incr) {
     border[round(place)] = '+';
     emptydata[round(place)] = '.';		/* tics in emptydata */
   }
@@ -267,17 +268,17 @@ static void plotarg(
 	double yf,  /* 		when the change is too big	*/
 	double zf)
 {
-  if (*device=='A'){
+  if (*device=='A') {
     auto char adata[MAXWIDTH+1];     /* actual data. copy emptydata, insert */
     char *xxs;				     /* string representation of xx */
-    memcpy((void*)adata,(void*)emptydata,MAXWIDTH); /* copy prototype */
+    memcpy(adata, emptydata, MAXWIDTH); /* copy prototype */
     xxs = ftos( xx, 11, 5, IO::formaat );
     if (zz != NOT_VALID)
       adata[point(zz,zlo,zhi,CONSSCALE,0,1)] = '+';/* zap data into string */
     adata[point(yy,ylo,yhi,CONSSCALE,0,1)] = '*';
     IO::plotout.form( "%-8.8s%s", xxs, adata );
     IO::plotout << '\n';
-  }else if (*device=='C'){
+  }else if (*device=='C') {
     static int xold, yold, zold;
     auto   int xpt,  ypt,  zpt;
     auto   int       dy,   dz;
@@ -285,21 +286,23 @@ static void plotarg(
     if (reset)
       xold = xpt;
     
-    if (zz != NOT_VALID){
+    if (zz != NOT_VALID) {
       zpt = point( zz, zhi, zlo, c->wh, c->top, true     );
       if (reset)
 	zold = zpt;
       dz = zpt - zold;
-      if ( !zf || ((double)abs(dz) < (double)(c->wh)*.8) )
+      if (!zf ||(static_cast<double>(abs(dz))<static_cast<double>(c->wh)*.8)) {
 	line( xold, zold, xpt, zpt, c->sec );
+      }
       zold = zpt;
     }
     ypt = point( yy, yhi, ylo, c->wh, c->top, true     );
     dy = ypt - yold;
     if (reset)
       yold = ypt;
-    if ( !yf || ((double)abs(dy) < (double)(c->wh)*.8) )
+    if (!yf || (static_cast<double>(abs(dy))<static_cast<double>(c->wh)*.8) ) {
       line( xold, yold, xpt, ypt, c->pri );
+    }
     yold = ypt;
     
     xold = xpt;
@@ -315,7 +318,7 @@ static void plotarg(
 static void crtopen(int , int fullgrid)
 {
   reset = true;
-  if (!fullgrid){
+  if (!fullgrid) {
     return;
   }
   crtplot = true;
@@ -334,8 +337,8 @@ static void crtopen(int , int fullgrid)
   int ii = 0;
   double lo[2], hi[2];
   for (PROBELIST::const_iterator i=PROBE_LISTS::plot[SIM::mode].begin();
-       i!=PROBE_LISTS::plot[SIM::mode].end(); ++i){
-    if (i->range() != 0.){
+       i!=PROBE_LISTS::plot[SIM::mode].end(); ++i) {
+    if (i->range() != 0.) {
       lo[ii] = i->lo();
       hi[ii] = i->hi();
     }else{
@@ -362,7 +365,7 @@ static void ycal(double ylo, double yhi, double zlo, double zhi)
   static char zstr[] = "           ";
   yrange = yhi-ylo;
   zrange = zhi-zlo;
-  for (double markno = 0.;  markno < OPT::ydivisions;  markno++){
+  for (double markno = 0.;  markno < OPT::ydivisions;  markno++) {
     ratio = markno / OPT::ydivisions;
     ynum = ylo + yrange * ratio ;
     znum = zlo + zrange * ratio ;
@@ -397,7 +400,7 @@ static void xcal(void)
   int cal;
   static char str[] = "           ";
   
-  for (double markno = 0.;  markno <= OPT::xdivisions;  markno++){
+  for (double markno = 0.;  markno <= OPT::xdivisions;  markno++) {
     ratio = markno / OPT::xdivisions;
     xcalib = (xlinswp)
       ? xstart +      (xstop-xstart) * ratio
