@@ -1,4 +1,4 @@
-/*$Id: s__.cc,v 18.5 2000/07/10 08:36:32 al Exp $ -*- C++ -*-
+/*$Id: s__.cc,v 19.16 2001/04/28 01:08:30 al Exp $ -*- C++ -*-
  * base class for simulation methods
  */
 #include "s__.h"
@@ -15,13 +15,13 @@ bool	SIM::uic = false;
 bool	SIM::bypass_ok = false;
 TRI_STATE SIM::inc_mode = tsNO;
 bool	SIM::fulldamp = false;
+bool	SIM::limiting = false;
 int	SIM::mode = sNONE;
 SIM::PHASE SIM::phase = pNONE;
 bool	SIM::freezetime = false;
 int*	SIM::nm = NULL;
 double*	SIM::i = NULL;
 double*	SIM::v0 = NULL;
-double*	SIM::vi1 = NULL;
 double*	SIM::vt1 = NULL;
 double*	SIM::fw = NULL;
 double*	SIM::vdc = NULL;
