@@ -1,4 +1,4 @@
-/*$Id: s__.h,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: s__.h,v 19.16 2001/04/28 01:08:30 al Exp $ -*- C++ -*-
  * base class for simulation methods
  */
 #ifndef S___H
@@ -44,7 +44,8 @@ public:
   static bool uic;		/* flag: use initial conditions (spice-like) */
   static bool bypass_ok;	/* flag: ok to bypass model evaluation */
   static TRI_STATE inc_mode;	/* flag: make incremental changes (3 state) */
-  static bool fulldamp;		/* flag: big iter. jump. use full (min) damp */
+  static bool fulldamp; 	/* flag: big iter. jump. use full (min) damp */
+  static bool limiting;		/* flag: node limiting */
   static int mode;		/* simulation type (AC, DC, ...) */
   static PHASE phase;		/* phase of simulation (iter, init-dc,) */
   static bool freezetime;	/* flag: don't advance stored time */
@@ -62,8 +63,8 @@ protected:
   static int	*nm;		/* node map (external to internal)	*/
   static double	*i;		/* dc-tran current (i) vector		*/
   static double	*v0;		/* dc-tran voltage, new			*/
-  static double	*vi1;		/* dc-tran voltage, 1 iter ago		*/
   static double	*vt1;		/* dc-tran voltage, 1 time ago		*/
+				/*    used only for logic status check	*/
   static double	*fw;		/* dc-tran fwd sub intermediate values	*/
   static double	*vdc;		/* saved dc voltages			*/
   static COMPLEX *ac;		/* ac right side			*/
@@ -104,7 +105,6 @@ protected:
  static void	order_reverse();
  static void	order_forward();
  static void	order_auto();
- static void	map_list(CARD_LIST&);
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */ 
 	PROBELIST& alarmlist();		/* s__out.cc */
 	PROBELIST& plotlist();
