@@ -1,16 +1,20 @@
-/*$Id: s__aux.cc,v 13.25 1999/04/04 05:18:21 al Exp $ -*- C++ -*-
+/*$Id: s__aux.cc,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
  * aux functions associated with the SIM class
  */
 #include "u_status.h"
 #include "s__.h"
 /*--------------------------------------------------------------------------*/
-//	void SIM::keep();
-//	void SIM::restore();
+void SIM::set_limit()
+{
+  for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
+    CKT_BASE::set_limit(v0[ii]);
+  }
+}
 /*--------------------------------------------------------------------------*/
 void SIM::keep()
 {
-  if (!freezetime){
-    for (int ii = 1;  ii <= STATUS::total_nodes;  ii++){
+  if (!freezetime) {
+    for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
       vdc[ii] = v0[ii];
     }
     last_time = (time0 > 0.) ? time0 : 0.;
@@ -19,8 +23,8 @@ void SIM::keep()
 /*--------------------------------------------------------------------------*/
 void SIM::restore()
 {
-  for (int ii = 1;  ii <= STATUS::total_nodes;  ii++){
-    v0[ii] = vdc[ii];
+  for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
+    vt1[ii] = v0[ii] = vdc[ii];
   }
 }
 /*--------------------------------------------------------------------------*/
