@@ -1,4 +1,4 @@
-/* $Id: s__init.cc,v 18.17 2000/09/04 09:45:33 al Exp $
+/* $Id: s__init.cc,v 19.16 2001/04/28 01:08:30 al Exp $
  * initialization (allocation, node mapping, etc)
  */
 #include "e_card.h"
@@ -176,19 +176,16 @@ void SIM::alloc_vectors()
   assert(!ac);		/* may be needed after exception */
   assert(!i);
   assert(!v0);
-  assert(!vi1);
   assert(!vt1);
   assert(!fw);
   ac = new COMPLEX[STATUS::total_nodes+1];
   i   = new double[STATUS::total_nodes+1];
   v0  = new double[STATUS::total_nodes+1];
-  vi1 = new double[STATUS::total_nodes+1];
   vt1 = new double[STATUS::total_nodes+1];
   fw  = new double[STATUS::total_nodes+1];
   std::fill_n(ac, STATUS::total_nodes+1, 0);
   std::fill_n(i,  STATUS::total_nodes+1, 0);
   std::fill_n(v0, STATUS::total_nodes+1, 0);
-  std::fill_n(vi1,STATUS::total_nodes+1, 0);
   std::fill_n(vt1,STATUS::total_nodes+1, 0);
   std::fill_n(fw, STATUS::total_nodes+1, 0);
 }
@@ -199,8 +196,6 @@ void SIM::alloc_vectors()
   i = NULL;
   delete [] v0;
   v0 = NULL;
-  delete [] vi1;
-  vi1 = NULL;
   delete [] vt1;
   vt1 = NULL;
   delete [] fw;
@@ -215,12 +210,10 @@ void SIM::alloc_vectors()
  */
 /*static*/ void SIM::uninit()
 {
-#if !defined(SGI_CC)	/* for some reason this generates bad code on 	    */
-  delete [] nstat;	/* SGI Indy with the native compiler (NCC or DCC)   */
-#endif			/* The linker reports something like "bad relocation*/
-  nstat = NULL;		/* entry".  This workaround causes a memory leak,   */
-  aa.reinit(0);		/* but at least you can compile it.		    */
-  lu.reinit(0);		/* g++ (2.6.3) does not have the problem.	    */
+  delete [] nstat;
+  nstat = NULL;
+  aa.reinit(0);
+  lu.reinit(0);
   acx.reinit(0);
   delete [] nm;
   nm = NULL;
