@@ -1,4 +1,4 @@
-/*$Id: s__map.cc,v 17.1 2000/02/19 08:51:13 al Exp $ -*- C++ -*-
+/*$Id: s__map.cc,v 19.3 2000/11/30 01:09:48 al Exp $ -*- C++ -*-
  * Allocates space for the admittance matrix.  Allocation below the
  * diagonal is by row, above the diagonal is by column, and stored backwards.
  * This broken vector is stored.  The length of it increases with increasing
@@ -14,7 +14,6 @@
 //static void	 SIM::order_reverse();
 //static void	 SIM::order_forward();
 //static void	 SIM::order_auto();
-//static void	 SIM::map_list(CARD*);
 /*--------------------------------------------------------------------------*/
 /* map_nodes: map intermediate node number to internal node number.
  * Ideally, this function would find some near-optimal order
@@ -24,7 +23,7 @@
 {
   nm = new int[STATUS::total_nodes+1];
   STATUS::order.reset().start();
-  switch (OPT::order){
+  switch (OPT::order) {
     default:
       error(bWARNING, "invalid order spec: %d\n", OPT::order);
     case oAUTO:	   order_auto();    break;
@@ -32,7 +31,7 @@
     case oFORWARD: order_forward(); break;
   }
   STATUS::order.stop();
-  map_list(CARD_LIST::card_list);
+  CARD_LIST::card_list.map_nodes();
 }
 /*--------------------------------------------------------------------------*/
 /* order_reverse: force ordering to reverse of user ordering
@@ -41,8 +40,9 @@
 /*static*/ void SIM::order_reverse()
 {
   nm[0] = 0;
-  for (int node = 1;  node <= STATUS::total_nodes;  ++node)
+  for (int node = 1;  node <= STATUS::total_nodes;  ++node) {
     nm[node] = STATUS::total_nodes - node + 1;
+  }
 }
 /*--------------------------------------------------------------------------*/
 /* order_forward: use user ordering, with subcircuits added to end
@@ -51,8 +51,9 @@
 /*static*/ void SIM::order_forward()
 {
   nm[0] = 0;
-  for (int node = 1;  node <= STATUS::total_nodes;  ++node)
+  for (int node = 1;  node <= STATUS::total_nodes;  ++node) {
     nm[node] = node;
+  }
 }
 /*--------------------------------------------------------------------------*/
 /* order_auto: full automatic ordering
@@ -61,27 +62,8 @@
 /*static*/ void SIM::order_auto()
 {
   nm[0] = 0;
-  for (int node = 1;  node <= STATUS::total_nodes;  ++node)
+  for (int node = 1;  node <= STATUS::total_nodes;  ++node) {
     nm[node] = STATUS::total_nodes - node + 1;
-}
-/*--------------------------------------------------------------------------*/
-/* map_list: map intermediate node to internal (working) node number.
- * recursive: actual mapping done here
- */
-/*static*/ void SIM::map_list(CARD_LIST& cl)
-{
-  for (CARD_LIST::iterator  ci = cl.begin();  ci != cl.end();  ++ci){
-    CARD* brh = *ci;
-    if (brh->is_device()){
-      int ii;
-      for (ii = 0;  brh->_n[ii].t != INVALIDNODE;  ii++){
-	brh->_n[ii].m = nm[brh->_n[ii].t];
-      }
-      brh->_n[ii].m = INVALIDNODE;
-      if (brh->subckt().exists()){
-	map_list(brh->subckt());
-      }
-    }
   }
 }
 /*--------------------------------------------------------------------------*/
