@@ -1,4 +1,4 @@
-/*$Id: s__solve.cc,v 18.5 2000/07/10 08:36:32 al Exp $ -*- C++ -*-
+/*$Id: s__solve.cc,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * solve one step of a transient or dc analysis
  */
 #include "e_card.h"
@@ -32,7 +32,7 @@ bool SIM::solve(int itl, int trace)
   
   do{
     if (trace >= tITERATION) {
-      print((double)-STATUS::iter[iSTEP]);
+      print(static_cast<double>(-STATUS::iter[iSTEP]));
     }
     set_flags();
     clear_arrays();
@@ -41,7 +41,13 @@ bool SIM::solve(int itl, int trace)
     evaluate_models();
 
     {if (converged) {
-      ++convergedcount;
+      {if (limiting) {
+	error(bDEBUG, "converged beyond limit, resetting limit\n");
+	set_limit();
+	convergedcount = 0;
+      }else{
+	++convergedcount;
+      }}
     }else{
       convergedcount = 0;
     }}
@@ -114,6 +120,7 @@ void SIM::count_iterations()
 /*--------------------------------------------------------------------------*/
 void SIM::set_flags()
 {
+  limiting = false;
   fulldamp = false;
   inc_mode = (inc_mode == tsBAD || OPT::incmode == false
 	      || STATUS::iter[iSTEP]==OPT::itl[OPT::TRLOW])
@@ -182,13 +189,8 @@ void SIM::load_matrix()
 /*--------------------------------------------------------------------------*/
 void SIM::solve_equations()
 {
-  double* vnew = vi1;	/* save last iter voltages by swapping arrays */
-  vi1 = v0;    
-  v0 = NULL;
-
   lu.lu_decomp(aa, bool(OPT::lubypass && SIM::inc_mode));
-  lu.fbsub(vnew, i, fw);
-  v0 = vnew;
+  lu.fbsub(v0, i, fw);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
