@@ -1,4 +1,4 @@
-/*$Id: s_ac_set.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: s_ac_set.cc,v 19.12 2001/02/24 03:40:45 al Exp $ -*- C++ -*-
  * ac analysis setup
  */
 #include "u_prblst.h"
@@ -44,8 +44,8 @@ void AC::setup(CS& cmd)
 
   int here = cmd.cursor();
   do{
-         if (cmd.pmatch("*$"))     times(cmd);
-    else if (cmd.pmatch("+$"))     by(cmd);
+         if (cmd.pmatch("*$$"))    times(cmd);
+    else if (cmd.pmatch("+$$"))    by(cmd);
     else if (cmd.pmatch("By"))     by(cmd);
     else if (cmd.pmatch("Decade")) decade(cmd);
     else if (cmd.pmatch("TImes"))  times(cmd);
@@ -63,7 +63,7 @@ void AC::setup(CS& cmd)
   cmd.check(bWARNING, "what's this?");
 
   IO::plotout = (ploton) ? IO::mstdout : OMSTREAM();
-  initio(out, IO::whence);
+  initio(out);
   if (needslinfix){			    // LIN option is # of points.
     untested();
     step=(stop-start)/(step-1.);	    // Must compute step after 
