@@ -1,4 +1,4 @@
-/*$Id: s_ac_swp.cc,v 15.2 1999/09/17 14:24:57 al Exp $ -*- C++ -*-
+/*$Id: s_ac_swp.cc,v 19.12 2001/02/24 03:40:45 al Exp $ -*- C++ -*-
  * ac sweep control
  */
 #include "l_compar.h"
@@ -29,22 +29,17 @@ void AC::first()
 /*--------------------------------------------------------------------------*/
 bool AC::next()
 {
-  if (IO::whence){
-    untested();
-    return true;
-  }
-
   double realstop = (linswp)
     ? stop - step/100.
     : stop / pow(step,.01);
-  if (!inorder(start, freq, realstop)){
+  if (!in_order(start, freq, realstop)){
     return false;
   }
 
   freq = (linswp)
     ? freq + step
     : freq * step;
-  if (inorder(freq, start, stop)){
+  if (in_order(freq, start, stop)){
     return false;
   }else{
     return true;
