@@ -1,4 +1,4 @@
-/*$Id: s_dc_set.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: s_dc_set.cc,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * dc analysis setup
  */
 #include "u_prblst.h"
@@ -17,7 +17,7 @@
 /*--------------------------------------------------------------------------*/
 void DCOP::finish(void)
 {
-  for (int ii = 0;  ii < DCNEST && exists(zap[ii]);  ii++){
+  for (int ii = 0;  ii < DCNEST && exists(zap[ii]);  ++ii) {
     stash[ii].restore();
     zap[ii]->dec_probes();
     zap[ii]->expand();
@@ -27,14 +27,14 @@ void DCOP::finish(void)
 /*--------------------------------------------------------------------------*/
 void OP::setup(CS& cmd)
 {
-  zap[0] = (CARD*)NULL;
+  zap[0] = NULL;
   sweepval[0] = &temp;
   start[0] = (cmd.is_float()) ? cmd.ctof()-ABS_ZERO : OPT::tempamb;
   stop[0]  = (cmd.is_float()) ? cmd.ctof()-ABS_ZERO : start[0];
   step[0] = 0.;
   genout = 0.;
   options(cmd);
-  if (step[0] == 0.){
+  if (step[0] == 0.) {
     step[0] = stop[0] - start[0];
     linswp[0] = true;
   }else{
@@ -45,15 +45,15 @@ void OP::setup(CS& cmd)
 void DC::setup(CS& cmd)
 {
   CARD_LIST::fat_iterator ci = findbranch(cmd, &CARD_LIST::card_list);
-  {if (!ci.isend()){
+  {if (!ci.isend()) {
     zap[0] = *ci;
-  }else if (cmd.is_float()){		/* sweep the generator */
-    zap[0] = (CARD*)NULL;
+  }else if (cmd.is_float()) {		/* sweep the generator */
+    zap[0] = NULL;
   }else{
     // leave as it was .. repeat cmd with no args
   }}
   
-  {if (cmd.is_float()){			/* set up parameters */
+  {if (cmd.is_float()) {			/* set up parameters */
     start[0] = cmd.ctof();
     stop[0] = (cmd.is_float()) ? cmd.ctof() : start[0];
     step[0] = 0.;
@@ -61,7 +61,7 @@ void DC::setup(CS& cmd)
     // leave it as it was .. repeat cmd with no args
   }}
   
-  {if (exists(zap[0])){ // component
+  {if (exists(zap[0])) { // component
     stash[0] = zap[0];			/* stash the std value */
     zap[0]->inc_probes();		/* we need to keep track of it */
     zap[0]->set_value(zap[0]->value(),0);/* zap out the extensions */
@@ -74,7 +74,7 @@ void DC::setup(CS& cmd)
   genout = 0.;
   temp = OPT::tempamb;
   options(cmd);
-  if (step[0] == 0.){	// prohibit log sweep from 0
+  if (step[0] == 0.) {	// prohibit log sweep from 0
     step[0] = stop[0] - start[0];
     linswp[0] = true;
   }
@@ -116,14 +116,14 @@ void DCOP::options(CS& cmd)
   cmd.check(bWARNING, "what's this?");
 
   IO::plotout = (ploton) ? IO::mstdout : OMSTREAM();
-  initio(out,(FILE*)NULL);
+  initio(out);
 }
 /*--------------------------------------------------------------------------*/
 void DCOP::by(CS& cmd)
 {
   step[0] = cmd.ctof();
   linswp[0] = true;
-  if (step[0] == 0.){
+  if (step[0] == 0.) {
     untested();
     step[0] = stop[0] - start[0];
   }
@@ -132,7 +132,7 @@ void DCOP::by(CS& cmd)
 void DCOP::decade(CS& cmd)
 {
   double junk = cmd.ctopf();
-  if (junk == 0.){
+  if (junk == 0.) {
     untested();
     junk = 1.;
   }
