@@ -1,4 +1,4 @@
-/*$Id: s_dc_swp.cc,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: s_dc_swp.cc,v 19.4 2001/01/13 21:33:15 al Exp $ -*- C++ -*-
  * dc analysis sweep
  */
 #include "l_denoise.h"
@@ -69,7 +69,7 @@ bool DCOP::next(int ii)
       if (!reverse) {
 	*(sweepval[ii]) += step[ii];
 	fixzero(sweepval[ii], step[ii]);
-	ok=inorder(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
+	ok=in_order(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
 	if (!ok  &&  loop) {
 	  reverse = true;
 	}
@@ -77,7 +77,7 @@ bool DCOP::next(int ii)
       if (reverse) {
 	*(sweepval[ii]) -= step[ii];
 	fixzero(sweepval[ii], step[ii]);
-	ok=inorder(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
+	ok=in_order(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
       }
     }}
   }else{
@@ -88,7 +88,7 @@ bool DCOP::next(int ii)
     }else{
       {if (!reverse) {
 	*(sweepval[ii]) *= step[ii];
-	ok=inorder(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
+	ok=in_order(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
 	if (!ok  &&  loop) {
 	  untested();
 	  reverse = true;
@@ -99,7 +99,7 @@ bool DCOP::next(int ii)
       if (reverse) {
 	untested();
 	*(sweepval[ii]) /= step[ii];
-	ok=inorder(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
+	ok=in_order(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
       }
     }}
   }}
