@@ -1,4 +1,4 @@
-/*$Id: s_tr_set.cc,v 18.7 2000/07/25 16:07:21 al Exp $ -*- C++ -*-
+/*$Id: s_tr_set.cc,v 19.25 2001/06/15 21:09:29 al Exp $ -*- C++ -*-
  * set up transient and fourier analysis
  */
 #include "u_prblst.h"
@@ -18,12 +18,12 @@ void TRANSIENT::setup(CS& cmd)
 {
   double oldrange = tstop - tstart;
   cont = true;
-  {if (cmd.is_pfloat()){
+  {if (cmd.is_pfloat()) {
     double arg1 = cmd.ctopf();
     double arg2 = cmd.ctopf();
     double arg3 = cmd.ctopf();
-    {if (arg3 != 0.){			    /* 3 args: all */
-      {if (arg1 == 0.  ||  arg1 > arg3){    /* eca (logical) order: */
+    {if (arg3 != 0.) {			    /* 3 args: all */
+      {if (arg1 == 0.  ||  arg1 > arg3) {   /* eca (logical) order: */
 	tstart = arg1;			    /* tstart tstop step */
 	tstop  = arg2;				
 	tstep  = arg3;
@@ -33,13 +33,13 @@ void TRANSIENT::setup(CS& cmd)
 	tstop  = arg2;
 	tstep  = arg1;
       }}
-    }else if (arg2 != 0.){		    /* 2 args */
-      {if (arg1 == 0.){			    /* 2 args: tstart, tstop */
+    }else if (arg2 != 0.) {		    /* 2 args */
+      {if (arg1 == 0.) {		    /* 2 args: tstart, tstop */
 	untested();
 	tstart = arg1;
 	tstop  = arg2;
 	/* tstep unchanged */
-      }else if (arg1 >= arg2){		    /* 2 args: tstop, tstep */
+      }else if (arg1 >= arg2) {		    /* 2 args: tstop, tstep */
 	tstart = last_time;
 	tstop  = arg1;
 	tstep  = arg2;
@@ -48,12 +48,12 @@ void TRANSIENT::setup(CS& cmd)
 	tstop  = arg2;
 	tstep  = arg1;
       }}
-    }else if (arg1 > last_time){	    /* 1 arg: tstop */
+    }else if (arg1 > last_time) {	    /* 1 arg: tstop */
       untested();
       tstart = last_time;
       tstop  = arg1;
       /* tstep unchanged */
-    }else if (arg1 == 0.){		    /* 1 arg: tstart */
+    }else if (arg1 == 0.) {		    /* 1 arg: tstart */
       //untested();
       tstart = 0.;
       tstop  = oldrange;
@@ -69,23 +69,22 @@ void TRANSIENT::setup(CS& cmd)
     tstop  = last_time + oldrange;
     /* tstep unchanged */
   }}
-  if (cmd.is_pfloat()){
+  if (cmd.is_pfloat()) {
     dtmax = abs(cmd.ctof());
-    skip = (int)(tstep / dtmax + .5);
+    skip = static_cast<int>(tstep / dtmax + .5);
   }
   options(cmd);
   
-  dtmax = tstep / (double)(skip);
+  dtmax = tstep / static_cast<double>(skip);
   dtmin = std::max(dtmin,dtmax/dtratio);
-  {if  (tstart < last_time  ||  last_time <= 0.){
+  {if  (tstart < last_time  ||  last_time <= 0.) {
     cont = false;
     time1 = time0 = 0.;
   }else{
     cont = true;
     time1 = time0 = last_time;
   }}
-  if (tstep==0.){
-    untested();
+  if (tstep==0.) {
     error(bERROR, "time step = 0\n");
   }
 }
@@ -128,11 +127,11 @@ void TRANSIENT::options(CS& cmd)
   }while (cmd.more() && !cmd.stuck(&here));
   cmd.check(bWARNING, "what's this?");
 
-  if (skip < 1){
+  if (skip < 1) {
     skip = 1;
   }
   IO::plotout = (ploton) ? IO::mstdout : OMSTREAM();
-  initio(out, IO::whence);
+  initio(out);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
