@@ -1,6 +1,7 @@
-/*$Id: u_opt2.cc,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
+/*$Id: u_opt2.cc,v 19.4 2001/01/13 21:33:15 al Exp $ -*- C++ -*-
  * command and functions to access OPT class
  */
+#include "l_compar.h"
 #include "s__.h"
 #include "constant.h"
 #include "ap.h"
@@ -149,6 +150,7 @@ bool OPT::set_values(CS& cmd)
     SIM::uninit();
     lowlim = 1 - reltol;
     uplim  = 1 + reltol;
+    numdgt = to_range(3, numdgt, 20);
   }
   return changed;
 }
