@@ -1,4 +1,4 @@
-/*$Id: u_probe.cc,v 18.5 2000/07/10 08:36:32 al Exp $ -*- C++ -*-
+/*$Id: u_probe.cc,v 19.14 2001/04/06 00:55:33 al Exp $ -*- C++ -*-
  * general probe object
  */
 #include "ap.h"
@@ -109,7 +109,7 @@ const std::string PROBE::label(void)const
   {if (!_brh){
     char string[BUFLEN+8];
     sprintf(string, "%s(%u)", _what.c_str(), _node);
-    return string;
+    return std::string(string);
   }else{
     return _what + '(' + _brh->long_label() + ')';
   }}
