@@ -1,4 +1,4 @@
-/*$Id: u_probe.h,v 18.4 2000/07/09 05:58:31 al Exp $ -*- C++ -*-
+/*$Id: u_probe.h,v 19.4 2001/01/13 21:33:15 al Exp $ -*- C++ -*-
  * single probe item
  */
 #ifndef U_PROBE_H
@@ -30,11 +30,11 @@ public:
   
   const std::string label()const;
   double	  value()const;
-  const CKT_BASE* object()const	{return _brh;}
-  double	  lo()const	{return _lo;}
-  double	  hi()const	{return _hi;}
-  double	  range()const	{return hi()-lo();}
-  bool		  inrange()const{return inorder(lo(),value(),hi());}
+  const CKT_BASE* object()const	 {return _brh;}
+  double	  lo()const	 {return _lo;}
+  double	  hi()const	 {return _hi;}
+  double	  range()const	 {return hi()-lo();}
+  bool		  in_range()const{return in_order(lo(),value(),hi());}
 private:
   double	  probe_node()const;
 };
