@@ -1,4 +1,4 @@
-/*$Id: u_statu2.cc,v 17.17 2000/04/21 08:13:58 al Exp $ -*- C++ -*-
+/*$Id: u_statu2.cc,v 19.6 2001/01/16 05:58:44 al Exp $ -*- C++ -*-
  * Displays the status of the system.  Makes all the calculations associated
  * with allocating memory but does not actually allocate it, unless necessary
  * to make the rest of the calculations.
@@ -63,8 +63,8 @@ void STATUS::command(CS& cmd)
 	  DEV_LOGIC::count(), DEV_SUBCKT::count());
   IO::mstdout.form(
 	  "commons: diodes=%d, mosfets=%d, gates=%d, subckts=%d\n",
-	  DIODE_COMMON::count(), MOS_COMMON::count(),
-	  LOGIC_COMMON::count(), SUBCKT_COMMON::count());
+	  COMMON_DIODE::count(), COMMON_MOS::count(),
+	  COMMON_LOGIC::count(), COMMON_SUBCKT::count());
   IO::mstdout.form(
 	  "models:  diodes=%d, mosfets=%d, gates=%d, subckts=%d\n",
 	  MODEL_DIODE::count(), MODEL_MOS_BASE::count(),
